"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import common.healthcheck.v1beta.healthcheck_pb2
import common.run.v1alpha.run_pb2
import core.mgmt.v1beta.mgmt_pb2
import google.longrunning.operations_pb2
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import sys
import typing
import vdp.pipeline.v1beta.common_pb2
import vdp.pipeline.v1beta.component_definition_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _State:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_State.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STATE_UNSPECIFIED: _State.ValueType  # 0
    """Unspecified."""
    STATE_INACTIVE: _State.ValueType  # 1
    """Inactive."""
    STATE_ACTIVE: _State.ValueType  # 2
    """Active."""
    STATE_ERROR: _State.ValueType  # 3
    """The pipeline has an error."""

class State(_State, metaclass=_StateEnumTypeWrapper):
    """State describes the state of a pipeline."""

STATE_UNSPECIFIED: State.ValueType  # 0
"""Unspecified."""
STATE_INACTIVE: State.ValueType  # 1
"""Inactive."""
STATE_ACTIVE: State.ValueType  # 2
"""Active."""
STATE_ERROR: State.ValueType  # 3
"""The pipeline has an error."""
global___State = State

@typing_extensions.final
class LivenessRequest(google.protobuf.message.Message):
    """LivenessRequest represents a request to check a service liveness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def health_check_request(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest:
        """HealthCheckRequest message"""
    def __init__(
        self,
        *,
        health_check_request: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_health_check_request", b"_health_check_request"]) -> typing_extensions.Literal["health_check_request"] | None: ...

global___LivenessRequest = LivenessRequest

@typing_extensions.final
class LivenessResponse(google.protobuf.message.Message):
    """LivenessResponse represents a response for a service liveness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def health_check_response(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse:
        """HealthCheckResponse message"""
    def __init__(
        self,
        *,
        health_check_response: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> None: ...

global___LivenessResponse = LivenessResponse

@typing_extensions.final
class ReadinessRequest(google.protobuf.message.Message):
    """ReadinessRequest represents a request to check a service readiness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def health_check_request(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest:
        """HealthCheckRequest message"""
    def __init__(
        self,
        *,
        health_check_request: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_health_check_request", b"_health_check_request"]) -> typing_extensions.Literal["health_check_request"] | None: ...

global___ReadinessRequest = ReadinessRequest

@typing_extensions.final
class ReadinessResponse(google.protobuf.message.Message):
    """ReadinessResponse represents a response for a service readiness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def health_check_response(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse:
        """HealthCheckResponse message"""
    def __init__(
        self,
        *,
        health_check_response: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> None: ...

global___ReadinessResponse = ReadinessResponse

@typing_extensions.final
class Endpoints(google.protobuf.message.Message):
    """Endpoints describe the endpoints of a pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class WebhookEndpoint(google.protobuf.message.Message):
        """WebhookEndpoint describe a webhook endpoint."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        URL_FIELD_NUMBER: builtins.int
        DESCRIPTION_FIELD_NUMBER: builtins.int
        url: builtins.str
        """Webhook URL."""
        description: builtins.str
        """Description."""
        def __init__(
            self,
            *,
            url: builtins.str = ...,
            description: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "url", b"url"]) -> None: ...

    @typing_extensions.final
    class WebhooksEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___Endpoints.WebhookEndpoint: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Endpoints.WebhookEndpoint | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    WEBHOOKS_FIELD_NUMBER: builtins.int
    @property
    def webhooks(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Endpoints.WebhookEndpoint]:
        """Webhook endpoints."""
    def __init__(
        self,
        *,
        webhooks: collections.abc.Mapping[builtins.str, global___Endpoints.WebhookEndpoint] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["webhooks", b"webhooks"]) -> None: ...

global___Endpoints = Endpoints

@typing_extensions.final
class Pipeline(google.protobuf.message.Message):
    """A Pipeline is an end-to-end workflow that automates a sequence of components
    to process data.

    For more information, see [Pipeline](https://www.instill.tech/docs/vdp/introduction) in
    the official documentation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _View:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ViewEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Pipeline._View.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VIEW_UNSPECIFIED: Pipeline._View.ValueType  # 0
        """Unspecified, equivalent to BASIC."""
        VIEW_BASIC: Pipeline._View.ValueType  # 1
        """Default view, only includes basic information."""
        VIEW_FULL: Pipeline._View.ValueType  # 2
        """Full representation."""
        VIEW_RECIPE: Pipeline._View.ValueType  # 3
        """Contains the recipe of the resource."""

    class View(_View, metaclass=_ViewEnumTypeWrapper):
        """View defines how a Pipeline is presented."""

    VIEW_UNSPECIFIED: Pipeline.View.ValueType  # 0
    """Unspecified, equivalent to BASIC."""
    VIEW_BASIC: Pipeline.View.ValueType  # 1
    """Default view, only includes basic information."""
    VIEW_FULL: Pipeline.View.ValueType  # 2
    """Full representation."""
    VIEW_RECIPE: Pipeline.View.ValueType  # 3
    """Contains the recipe of the resource."""

    class _Visibility:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _VisibilityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Pipeline._Visibility.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VISIBILITY_UNSPECIFIED: Pipeline._Visibility.ValueType  # 0
        """Unspecified, equivalent to PRIVATE."""
        VISIBILITY_PRIVATE: Pipeline._Visibility.ValueType  # 1
        """Only the user can see the pipeline."""
        VISIBILITY_PUBLIC: Pipeline._Visibility.ValueType  # 2
        """Other users can see the pipeline."""

    class Visibility(_Visibility, metaclass=_VisibilityEnumTypeWrapper):
        """Visibility defines who can access the pipeline."""

    VISIBILITY_UNSPECIFIED: Pipeline.Visibility.ValueType  # 0
    """Unspecified, equivalent to PRIVATE."""
    VISIBILITY_PRIVATE: Pipeline.Visibility.ValueType  # 1
    """Only the user can see the pipeline."""
    VISIBILITY_PUBLIC: Pipeline.Visibility.ValueType  # 2
    """Other users can see the pipeline."""

    @typing_extensions.final
    class Stats(google.protobuf.message.Message):
        """Statistic data"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NUMBER_OF_RUNS_FIELD_NUMBER: builtins.int
        LAST_RUN_TIME_FIELD_NUMBER: builtins.int
        NUMBER_OF_CLONES_FIELD_NUMBER: builtins.int
        number_of_runs: builtins.int
        """Number of pipeline runs."""
        @property
        def last_run_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
            """Last run time."""
        number_of_clones: builtins.int
        """Number of times this pipeline has been cloned."""
        def __init__(
            self,
            *,
            number_of_runs: builtins.int = ...,
            last_run_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            number_of_clones: builtins.int = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["last_run_time", b"last_run_time"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["last_run_time", b"last_run_time", "number_of_clones", b"number_of_clones", "number_of_runs", b"number_of_runs"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RECIPE_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    DELETE_TIME_FIELD_NUMBER: builtins.int
    SHARING_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    OWNER_NAME_FIELD_NUMBER: builtins.int
    RELEASES_FIELD_NUMBER: builtins.int
    README_FIELD_NUMBER: builtins.int
    PERMISSION_FIELD_NUMBER: builtins.int
    VISIBILITY_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    DATA_SPECIFICATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    STATS_FIELD_NUMBER: builtins.int
    RAW_RECIPE_FIELD_NUMBER: builtins.int
    SOURCE_URL_FIELD_NUMBER: builtins.int
    DOCUMENTATION_URL_FIELD_NUMBER: builtins.int
    LICENSE_FIELD_NUMBER: builtins.int
    PROFILE_IMAGE_FIELD_NUMBER: builtins.int
    ENDPOINTS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the pipeline, defined by its parent and ID.
    - Format: `{parent_type}/{parent.id}/pipelines/{pipeline.id}`.
    """
    uid: builtins.str
    """Pipeline UUID."""
    id: builtins.str
    """Pipeline resource ID (used in `name` as the last segment). This conforms
    to RFC-1034, which restricts to letters, numbers, and hyphen, with the
    first character a letter, the last a letter or a number, and a 63
    character maximum.
    """
    description: builtins.str
    """Pipeline description."""
    @property
    def recipe(self) -> google.protobuf.struct_pb2.Struct:
        """Recipe describes the components of a Pipeline and how they are connected."""
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Pipeline creation time."""
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Pipeline update time."""
    @property
    def delete_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Pipeline delete time."""
    @property
    def sharing(self) -> vdp.pipeline.v1beta.common_pb2.Sharing:
        """Pipeline sharing information."""
    @property
    def metadata(self) -> google.protobuf.struct_pb2.Struct:
        """Metadata holds console-related data such as the pipeline builder layout."""
    owner_name: builtins.str
    """Owner Name."""
    @property
    def releases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineRelease]:
        """Releases holds the history of pipeline versions."""
    readme: builtins.str
    """README holds the pipeline documentation."""
    @property
    def permission(self) -> vdp.pipeline.v1beta.common_pb2.Permission:
        """Permission defines how a pipeline can be used."""
    visibility: global___Pipeline.Visibility.ValueType
    """Pipeline visibility."""
    @property
    def owner(self) -> core.mgmt.v1beta.mgmt_pb2.Owner:
        """Pipeline owner."""
    @property
    def data_specification(self) -> vdp.pipeline.v1beta.component_definition_pb2.DataSpecification:
        """Data specifications."""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Tags."""
    @property
    def stats(self) -> global___Pipeline.Stats:
        """Statistic data."""
    raw_recipe: builtins.str
    """Recipe in YAML format describes the components of a pipeline and how they
    are connected.
    """
    source_url: builtins.str
    """A link to the source code of the pipeline (e.g. to a GitHub repository)."""
    documentation_url: builtins.str
    """A link to any extra information."""
    license: builtins.str
    """License under which the pipeline is distributed."""
    profile_image: builtins.str
    """Pipeline profile image in base64 format."""
    @property
    def endpoints(self) -> global___Endpoints:
        """Pipeline endpoints."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        uid: builtins.str = ...,
        id: builtins.str = ...,
        description: builtins.str | None = ...,
        recipe: google.protobuf.struct_pb2.Struct | None = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        delete_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        sharing: vdp.pipeline.v1beta.common_pb2.Sharing | None = ...,
        metadata: google.protobuf.struct_pb2.Struct | None = ...,
        owner_name: builtins.str = ...,
        releases: collections.abc.Iterable[global___PipelineRelease] | None = ...,
        readme: builtins.str = ...,
        permission: vdp.pipeline.v1beta.common_pb2.Permission | None = ...,
        visibility: global___Pipeline.Visibility.ValueType = ...,
        owner: core.mgmt.v1beta.mgmt_pb2.Owner | None = ...,
        data_specification: vdp.pipeline.v1beta.component_definition_pb2.DataSpecification | None = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        stats: global___Pipeline.Stats | None = ...,
        raw_recipe: builtins.str = ...,
        source_url: builtins.str | None = ...,
        documentation_url: builtins.str | None = ...,
        license: builtins.str | None = ...,
        profile_image: builtins.str | None = ...,
        endpoints: global___Endpoints | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_description", b"_description", "_documentation_url", b"_documentation_url", "_license", b"_license", "_owner", b"_owner", "_profile_image", b"_profile_image", "_source_url", b"_source_url", "create_time", b"create_time", "data_specification", b"data_specification", "delete_time", b"delete_time", "description", b"description", "documentation_url", b"documentation_url", "endpoints", b"endpoints", "license", b"license", "metadata", b"metadata", "owner", b"owner", "permission", b"permission", "profile_image", b"profile_image", "recipe", b"recipe", "sharing", b"sharing", "source_url", b"source_url", "stats", b"stats", "update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_description", b"_description", "_documentation_url", b"_documentation_url", "_license", b"_license", "_owner", b"_owner", "_profile_image", b"_profile_image", "_source_url", b"_source_url", "create_time", b"create_time", "data_specification", b"data_specification", "delete_time", b"delete_time", "description", b"description", "documentation_url", b"documentation_url", "endpoints", b"endpoints", "id", b"id", "license", b"license", "metadata", b"metadata", "name", b"name", "owner", b"owner", "owner_name", b"owner_name", "permission", b"permission", "profile_image", b"profile_image", "raw_recipe", b"raw_recipe", "readme", b"readme", "recipe", b"recipe", "releases", b"releases", "sharing", b"sharing", "source_url", b"source_url", "stats", b"stats", "tags", b"tags", "uid", b"uid", "update_time", b"update_time", "visibility", b"visibility"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_description", b"_description"]) -> typing_extensions.Literal["description"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_documentation_url", b"_documentation_url"]) -> typing_extensions.Literal["documentation_url"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_license", b"_license"]) -> typing_extensions.Literal["license"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_owner", b"_owner"]) -> typing_extensions.Literal["owner"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_profile_image", b"_profile_image"]) -> typing_extensions.Literal["profile_image"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_source_url", b"_source_url"]) -> typing_extensions.Literal["source_url"] | None: ...

global___Pipeline = Pipeline

@typing_extensions.final
class TriggerMetadata(google.protobuf.message.Message):
    """TriggerMetadata contains the traces of the pipeline inference."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TracesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___Trace: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Trace | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TRACES_FIELD_NUMBER: builtins.int
    @property
    def traces(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Trace]:
        """Each key in the `traces` object is a component ID. The value is a Trace
        object containing the execution details.
        """
    def __init__(
        self,
        *,
        traces: collections.abc.Mapping[builtins.str, global___Trace] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["traces", b"traces"]) -> None: ...

global___TriggerMetadata = TriggerMetadata

@typing_extensions.final
class Trace(google.protobuf.message.Message):
    """Trace contains the execution details of a component."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Trace._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Trace._Status.ValueType  # 0
        """Unspecified."""
        STATUS_COMPLETED: Trace._Status.ValueType  # 1
        """Successfully completed."""
        STATUS_SKIPPED: Trace._Status.ValueType  # 2
        """Skipped."""
        STATUS_ERROR: Trace._Status.ValueType  # 3
        """Aborted with error."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Status holds the the component execution outcome."""

    STATUS_UNSPECIFIED: Trace.Status.ValueType  # 0
    """Unspecified."""
    STATUS_COMPLETED: Trace.Status.ValueType  # 1
    """Successfully completed."""
    STATUS_SKIPPED: Trace.Status.ValueType  # 2
    """Skipped."""
    STATUS_ERROR: Trace.Status.ValueType  # 3
    """Aborted with error."""

    STATUSES_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    OUTPUTS_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    COMPUTE_TIME_IN_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def statuses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___Trace.Status.ValueType]:
        """Statuses contains an execution status per input."""
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Component inputs."""
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Component outputs."""
    @property
    def error(self) -> google.protobuf.struct_pb2.Struct:
        """Error details."""
    compute_time_in_seconds: builtins.float
    """Computation time in seconds."""
    def __init__(
        self,
        *,
        statuses: collections.abc.Iterable[global___Trace.Status.ValueType] | None = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        error: google.protobuf.struct_pb2.Struct | None = ...,
        compute_time_in_seconds: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["error", b"error"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_time_in_seconds", b"compute_time_in_seconds", "error", b"error", "inputs", b"inputs", "outputs", b"outputs", "statuses", b"statuses"]) -> None: ...

global___Trace = Trace

@typing_extensions.final
class GetHubStatsRequest(google.protobuf.message.Message):
    """GetHubStatsRequest represents a request to get hub stats."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetHubStatsRequest = GetHubStatsRequest

@typing_extensions.final
class GetHubStatsResponse(google.protobuf.message.Message):
    """GetHubStatsResponse represents a response to get hub stats."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUMBER_OF_PUBLIC_PIPELINES_FIELD_NUMBER: builtins.int
    NUMBER_OF_FEATURED_PIPELINES_FIELD_NUMBER: builtins.int
    number_of_public_pipelines: builtins.int
    """Total number of public pipelines."""
    number_of_featured_pipelines: builtins.int
    """Total number of featured pipelines."""
    def __init__(
        self,
        *,
        number_of_public_pipelines: builtins.int = ...,
        number_of_featured_pipelines: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["number_of_featured_pipelines", b"number_of_featured_pipelines", "number_of_public_pipelines", b"number_of_public_pipelines"]) -> None: ...

global___GetHubStatsResponse = GetHubStatsResponse

@typing_extensions.final
class PipelineRelease(google.protobuf.message.Message):
    """Pipeline releases contain the version control information of a pipeline.
    This allows users to track changes in the pipeline over time.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RECIPE_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    DELETE_TIME_FIELD_NUMBER: builtins.int
    ALIAS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    README_FIELD_NUMBER: builtins.int
    DATA_SPECIFICATION_FIELD_NUMBER: builtins.int
    RAW_RECIPE_FIELD_NUMBER: builtins.int
    ENDPOINTS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the release, defined by its parent and ID.
    - Format: `{parent_type}/{parent.id}/pipelines/{pipeline.id}/releases/{release.id}`.
    """
    uid: builtins.str
    """Release UUID."""
    id: builtins.str
    """Release resource ID (used in `name` as the last segment). It must be a
    sematic version vX.Y.Z.
    """
    description: builtins.str
    """Release description."""
    @property
    def recipe(self) -> google.protobuf.struct_pb2.Struct:
        """Recipe of the versioned pipeline."""
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Pipeline creation time."""
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Pipeline update time."""
    @property
    def delete_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Pipeline deletion time."""
    alias: builtins.str
    """Alias."""
    @property
    def metadata(self) -> google.protobuf.struct_pb2.Struct:
        """Key-value object with console-related data such as the pipeline builder
        layout.
        """
    readme: builtins.str
    """README."""
    @property
    def data_specification(self) -> vdp.pipeline.v1beta.component_definition_pb2.DataSpecification:
        """Data specifications."""
    raw_recipe: builtins.str
    """Recipe in YAML format describes the components of a pipeline and how they
    are connected.
    """
    @property
    def endpoints(self) -> global___Endpoints:
        """Pipeline endpoints."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        uid: builtins.str = ...,
        id: builtins.str = ...,
        description: builtins.str | None = ...,
        recipe: google.protobuf.struct_pb2.Struct | None = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        delete_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        alias: builtins.str = ...,
        metadata: google.protobuf.struct_pb2.Struct | None = ...,
        readme: builtins.str = ...,
        data_specification: vdp.pipeline.v1beta.component_definition_pb2.DataSpecification | None = ...,
        raw_recipe: builtins.str = ...,
        endpoints: global___Endpoints | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_description", b"_description", "create_time", b"create_time", "data_specification", b"data_specification", "delete_time", b"delete_time", "description", b"description", "endpoints", b"endpoints", "metadata", b"metadata", "recipe", b"recipe", "update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_description", b"_description", "alias", b"alias", "create_time", b"create_time", "data_specification", b"data_specification", "delete_time", b"delete_time", "description", b"description", "endpoints", b"endpoints", "id", b"id", "metadata", b"metadata", "name", b"name", "raw_recipe", b"raw_recipe", "readme", b"readme", "recipe", b"recipe", "uid", b"uid", "update_time", b"update_time"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_description", b"_description"]) -> typing_extensions.Literal["description"] | None: ...

global___PipelineRelease = PipelineRelease

@typing_extensions.final
class ListPipelinesRequest(google.protobuf.message.Message):
    """ListPipelinesRequest represents a request to list pipelines."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    SHOW_DELETED_FIELD_NUMBER: builtins.int
    VISIBILITY_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of pipelines to return. If this parameter is
    unspecified, at most 10 pipelines will be returned. The cap value for this
    parameter is 100 (i.e. any value above that will be coerced to 100).
    """
    page_token: builtins.str
    """Page token."""
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired pipeline view in the response."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    - Example:
    `recipe.components.definition_name:"operator-definitions/2ac8be70-0f7a-4b61-a33d-098b8acfa6f3"`.
    """
    show_deleted: builtins.bool
    """Include soft-deleted pipelines in the result."""
    visibility: global___Pipeline.Visibility.ValueType
    """Limit results to pipelines with the specified visibility."""
    order_by: builtins.str
    """Order by field, with options for ordering by `id`, `create_time` or `update_time`.
    Format: `order_by=id` or `order_by=create_time desc`, default is `asc`.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        view: global___Pipeline.View.ValueType | None = ...,
        filter: builtins.str | None = ...,
        show_deleted: builtins.bool | None = ...,
        visibility: global___Pipeline.Visibility.ValueType | None = ...,
        order_by: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_order_by", b"_order_by", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "_visibility", b"_visibility", "filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view", "visibility", b"visibility"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_order_by", b"_order_by", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "_visibility", b"_visibility", "filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view", "visibility", b"visibility"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_order_by", b"_order_by"]) -> typing_extensions.Literal["order_by"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_show_deleted", b"_show_deleted"]) -> typing_extensions.Literal["show_deleted"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_visibility", b"_visibility"]) -> typing_extensions.Literal["visibility"] | None: ...

global___ListPipelinesRequest = ListPipelinesRequest

@typing_extensions.final
class ListPipelinesResponse(google.protobuf.message.Message):
    """ListPipelinesResponse contains a list of pipelines."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def pipelines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Pipeline]:
        """A list of pipeline resources."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of pipelines."""
    def __init__(
        self,
        *,
        pipelines: collections.abc.Iterable[global___Pipeline] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "pipelines", b"pipelines", "total_size", b"total_size"]) -> None: ...

global___ListPipelinesResponse = ListPipelinesResponse

@typing_extensions.final
class ListNamespacePipelinesRequest(google.protobuf.message.Message):
    """ListNamespacePipelinesRequest represents a request to list pipelines."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    SHOW_DELETED_FIELD_NUMBER: builtins.int
    VISIBILITY_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    page_size: builtins.int
    """The maximum number of pipelines to return. If this parameter is
    unspecified, at most 10 pipelines will be returned. The cap value for this
    parameter is 100 (i.e. any value above that will be coerced to 100).
    """
    page_token: builtins.str
    """Page token."""
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired pipeline view in the response."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    - Example:
    `recipe.components.definition_name:"operator-definitions/2ac8be70-0f7a-4b61-a33d-098b8acfa6f3"`.
    """
    show_deleted: builtins.bool
    """Include soft-deleted pipelines in the result."""
    visibility: global___Pipeline.Visibility.ValueType
    """Limit results to pipelines with the specified visibility."""
    order_by: builtins.str
    """Order by field, with options for ordering by `id`, `create_time` or `update_time`.
    Format: `order_by=id` or `order_by=create_time desc`, default is `asc`.
    """
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        view: global___Pipeline.View.ValueType | None = ...,
        filter: builtins.str | None = ...,
        show_deleted: builtins.bool | None = ...,
        visibility: global___Pipeline.Visibility.ValueType | None = ...,
        order_by: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_order_by", b"_order_by", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "_visibility", b"_visibility", "filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view", "visibility", b"visibility"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_order_by", b"_order_by", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "_visibility", b"_visibility", "filter", b"filter", "namespace_id", b"namespace_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view", "visibility", b"visibility"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_order_by", b"_order_by"]) -> typing_extensions.Literal["order_by"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_show_deleted", b"_show_deleted"]) -> typing_extensions.Literal["show_deleted"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_visibility", b"_visibility"]) -> typing_extensions.Literal["visibility"] | None: ...

global___ListNamespacePipelinesRequest = ListNamespacePipelinesRequest

@typing_extensions.final
class ListNamespacePipelinesResponse(google.protobuf.message.Message):
    """ListNamespacePipelinesResponse contains a list of pipelines."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def pipelines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Pipeline]:
        """A list of pipeline resources."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of pipelines."""
    def __init__(
        self,
        *,
        pipelines: collections.abc.Iterable[global___Pipeline] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "pipelines", b"pipelines", "total_size", b"total_size"]) -> None: ...

global___ListNamespacePipelinesResponse = ListNamespacePipelinesResponse

@typing_extensions.final
class LookUpPipelineRequest(google.protobuf.message.Message):
    """LookUpPipelineRequest represents a request to query a pipeline by its UID."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERMALINK_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    permalink: builtins.str
    """The permalink of the pipeline, which allows its access by UID.
    - Format: `pipelines/{pipeline.uid}`.
    """
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired pipeline view in the response."""
    def __init__(
        self,
        *,
        permalink: builtins.str = ...,
        view: global___Pipeline.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "permalink", b"permalink", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___LookUpPipelineRequest = LookUpPipelineRequest

@typing_extensions.final
class LookUpPipelineResponse(google.protobuf.message.Message):
    """LookUpPipelineResponse contains the requested pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The requested pipeline."""
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> None: ...

global___LookUpPipelineResponse = LookUpPipelineResponse

@typing_extensions.final
class CreateNamespacePipelineRequest(google.protobuf.message.Message):
    """CreateNamespacePipelineRequest represents a request from a namespace to create a
    pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """The namespace that creates the pipeline."""
    @property
    def pipeline(self) -> global___Pipeline:
        """The properties of the pipeline to be created."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline: global___Pipeline | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespace_id", b"namespace_id", "pipeline", b"pipeline"]) -> None: ...

global___CreateNamespacePipelineRequest = CreateNamespacePipelineRequest

@typing_extensions.final
class CreateNamespacePipelineResponse(google.protobuf.message.Message):
    """CreateNamespacePipelineResponse contains the created pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The created pipeline resource."""
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> None: ...

global___CreateNamespacePipelineResponse = CreateNamespacePipelineResponse

@typing_extensions.final
class GetNamespacePipelineRequest(google.protobuf.message.Message):
    """GetNamespacePipelineRequest represents a request to fetch the details of a
    pipeline owned by a namespace.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired pipeline view in the response."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        view: global___Pipeline.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "namespace_id", b"namespace_id", "pipeline_id", b"pipeline_id", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___GetNamespacePipelineRequest = GetNamespacePipelineRequest

@typing_extensions.final
class GetNamespacePipelineResponse(google.protobuf.message.Message):
    """GetNamespacePipelineResponse contains the requested pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The pipeline resource."""
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> None: ...

global___GetNamespacePipelineResponse = GetNamespacePipelineResponse

@typing_extensions.final
class UpdateNamespacePipelineRequest(google.protobuf.message.Message):
    """UpdateNamespacePipelineRequest represents a request to update a pipeline owned by
    a namespace.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    @property
    def pipeline(self) -> global___Pipeline:
        """The pipeline fields that will replace the existing ones."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """The update mask specifies the subset of fields that should be modified.

        For more information about this field, see
        https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#field-mask.
        """
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        pipeline: global___Pipeline | None = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespace_id", b"namespace_id", "pipeline", b"pipeline", "pipeline_id", b"pipeline_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateNamespacePipelineRequest = UpdateNamespacePipelineRequest

@typing_extensions.final
class UpdateNamespacePipelineResponse(google.protobuf.message.Message):
    """UpdateNamespacePipelineResponse contains the updated pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The updated pipeline resource."""
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> None: ...

global___UpdateNamespacePipelineResponse = UpdateNamespacePipelineResponse

@typing_extensions.final
class DeleteNamespacePipelineRequest(google.protobuf.message.Message):
    """DeleteNamespacePipelineRequest represents a request to delete a pipeline owned by
    a namespace.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespace_id", b"namespace_id", "pipeline_id", b"pipeline_id"]) -> None: ...

global___DeleteNamespacePipelineRequest = DeleteNamespacePipelineRequest

@typing_extensions.final
class DeleteNamespacePipelineResponse(google.protobuf.message.Message):
    """DeleteNamespacePipelineResponse is an empty response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteNamespacePipelineResponse = DeleteNamespacePipelineResponse

@typing_extensions.final
class ValidateNamespacePipelineRequest(google.protobuf.message.Message):
    """ValidateNamespacePipelineRequest represents a request to validate a pipeline
    owned by a user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespace_id", b"namespace_id", "pipeline_id", b"pipeline_id"]) -> None: ...

global___ValidateNamespacePipelineRequest = ValidateNamespacePipelineRequest

@typing_extensions.final
class ValidateNamespacePipelineResponse(google.protobuf.message.Message):
    """ValidateNamespacePipelineResponse contains a validated pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    ERRORS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    """Success"""
    @property
    def errors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ErrPipelineValidation]:
        """The validated pipeline resource."""
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
        errors: collections.abc.Iterable[global___ErrPipelineValidation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["errors", b"errors", "success", b"success"]) -> None: ...

global___ValidateNamespacePipelineResponse = ValidateNamespacePipelineResponse

@typing_extensions.final
class RenameNamespacePipelineRequest(google.protobuf.message.Message):
    """RenameNamespacePipelineRequest represents a request to rename the name of a
    pipeline owned by a namespace.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    NEW_PIPELINE_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    new_pipeline_id: builtins.str
    """The new resource ID. This will transform the resource name into
    `namespaces/{namespace.id}/pipelines/{new_pipeline_id}`.
    """
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        new_pipeline_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespace_id", b"namespace_id", "new_pipeline_id", b"new_pipeline_id", "pipeline_id", b"pipeline_id"]) -> None: ...

global___RenameNamespacePipelineRequest = RenameNamespacePipelineRequest

@typing_extensions.final
class RenameNamespacePipelineResponse(google.protobuf.message.Message):
    """RenameNamespacePipelineResponse contains a renamed pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The renamed pipeline resource."""
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> None: ...

global___RenameNamespacePipelineResponse = RenameNamespacePipelineResponse

@typing_extensions.final
class CloneNamespacePipelineRequest(google.protobuf.message.Message):
    """CloneNamespacePipelineRequest represents a request to clone a pipeline owned by a
    user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SHARING_FIELD_NUMBER: builtins.int
    TARGET_NAMESPACE_ID_FIELD_NUMBER: builtins.int
    TARGET_PIPELINE_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    description: builtins.str
    """Pipeline description."""
    @property
    def sharing(self) -> vdp.pipeline.v1beta.common_pb2.Sharing:
        """Pipeline sharing information."""
    target_namespace_id: builtins.str
    """Target Namespace ID."""
    target_pipeline_id: builtins.str
    """Target Pipeline ID."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        description: builtins.str = ...,
        sharing: vdp.pipeline.v1beta.common_pb2.Sharing | None = ...,
        target_namespace_id: builtins.str = ...,
        target_pipeline_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sharing", b"sharing"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "namespace_id", b"namespace_id", "pipeline_id", b"pipeline_id", "sharing", b"sharing", "target_namespace_id", b"target_namespace_id", "target_pipeline_id", b"target_pipeline_id"]) -> None: ...

global___CloneNamespacePipelineRequest = CloneNamespacePipelineRequest

@typing_extensions.final
class CloneNamespacePipelineResponse(google.protobuf.message.Message):
    """CloneNamespacePipelineResponse contains a cloned pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CloneNamespacePipelineResponse = CloneNamespacePipelineResponse

@typing_extensions.final
class CloneNamespacePipelineReleaseRequest(google.protobuf.message.Message):
    """CloneNamespacePipelineReleaseRequest represents a request to clone a pipeline
    release owned by a user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    RELEASE_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SHARING_FIELD_NUMBER: builtins.int
    TARGET_NAMESPACE_ID_FIELD_NUMBER: builtins.int
    TARGET_PIPELINE_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    release_id: builtins.str
    """Release ID"""
    description: builtins.str
    """Pipeline description."""
    @property
    def sharing(self) -> vdp.pipeline.v1beta.common_pb2.Sharing:
        """Pipeline sharing information."""
    target_namespace_id: builtins.str
    """Target Namespace ID."""
    target_pipeline_id: builtins.str
    """Target Pipeline ID."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        release_id: builtins.str = ...,
        description: builtins.str = ...,
        sharing: vdp.pipeline.v1beta.common_pb2.Sharing | None = ...,
        target_namespace_id: builtins.str = ...,
        target_pipeline_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sharing", b"sharing"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "namespace_id", b"namespace_id", "pipeline_id", b"pipeline_id", "release_id", b"release_id", "sharing", b"sharing", "target_namespace_id", b"target_namespace_id", "target_pipeline_id", b"target_pipeline_id"]) -> None: ...

global___CloneNamespacePipelineReleaseRequest = CloneNamespacePipelineReleaseRequest

@typing_extensions.final
class CloneNamespacePipelineReleaseResponse(google.protobuf.message.Message):
    """CloneNamespacePipelineReleaseResponse contains a cloned pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CloneNamespacePipelineReleaseResponse = CloneNamespacePipelineReleaseResponse

@typing_extensions.final
class SendNamespacePipelineEventRequest(google.protobuf.message.Message):
    """SendNamespacePipelineEventRequest"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    event: builtins.str
    """Event"""
    code: builtins.str
    """Code"""
    @property
    def data(self) -> google.protobuf.struct_pb2.Struct:
        """Input data"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        event: builtins.str = ...,
        code: builtins.str = ...,
        data: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "data", b"data", "event", b"event", "namespace_id", b"namespace_id", "pipeline_id", b"pipeline_id"]) -> None: ...

global___SendNamespacePipelineEventRequest = SendNamespacePipelineEventRequest

@typing_extensions.final
class SendNamespacePipelineEventResponse(google.protobuf.message.Message):
    """SendNamespacePipelineEventResponse"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.struct_pb2.Struct:
        """data"""
    def __init__(
        self,
        *,
        data: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data"]) -> None: ...

global___SendNamespacePipelineEventResponse = SendNamespacePipelineEventResponse

@typing_extensions.final
class SendNamespacePipelineReleaseEventRequest(google.protobuf.message.Message):
    """SendNamespacePipelineReleaseEventRequest"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    RELEASE_ID_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    release_id: builtins.str
    """Pipeline ID"""
    event: builtins.str
    """Event"""
    code: builtins.str
    """Code"""
    @property
    def data(self) -> google.protobuf.struct_pb2.Struct:
        """Input data"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        release_id: builtins.str = ...,
        event: builtins.str = ...,
        code: builtins.str = ...,
        data: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "data", b"data", "event", b"event", "namespace_id", b"namespace_id", "pipeline_id", b"pipeline_id", "release_id", b"release_id"]) -> None: ...

global___SendNamespacePipelineReleaseEventRequest = SendNamespacePipelineReleaseEventRequest

@typing_extensions.final
class SendNamespacePipelineReleaseEventResponse(google.protobuf.message.Message):
    """SendNamespacePipelineReleaseEventResponse"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.struct_pb2.Struct:
        """data"""
    def __init__(
        self,
        *,
        data: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data"]) -> None: ...

global___SendNamespacePipelineReleaseEventResponse = SendNamespacePipelineReleaseEventResponse

@typing_extensions.final
class TriggerNamespacePipelineRequest(google.protobuf.message.Message):
    """TriggerNamespacePipelineRequest represents a request to trigger a user-owned
    pipeline synchronously.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Pipeline input parameters, it will be deprecated soon."""
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TriggerData]:
        """Data"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        data: collections.abc.Iterable[global___TriggerData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "inputs", b"inputs", "namespace_id", b"namespace_id", "pipeline_id", b"pipeline_id"]) -> None: ...

global___TriggerNamespacePipelineRequest = TriggerNamespacePipelineRequest

@typing_extensions.final
class TriggerNamespacePipelineResponse(google.protobuf.message.Message):
    """TriggerNamespacePipelineResponse contains the pipeline execution results, i.e.,
    the multiple model inference outputs.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUTS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Model inference outputs."""
    @property
    def metadata(self) -> global___TriggerMetadata:
        """Traces of the pipeline inference."""
    def __init__(
        self,
        *,
        outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        metadata: global___TriggerMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "outputs", b"outputs"]) -> None: ...

global___TriggerNamespacePipelineResponse = TriggerNamespacePipelineResponse

@typing_extensions.final
class TriggerNamespacePipelineWithStreamRequest(google.protobuf.message.Message):
    """TriggerNamespacePipelineWithStreamRequest represents a request to trigger a user-owned
    pipeline synchronously and streams back the results.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Pipeline input parameters, it will be deprecated soon."""
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TriggerData]:
        """Data"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        data: collections.abc.Iterable[global___TriggerData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "inputs", b"inputs", "namespace_id", b"namespace_id", "pipeline_id", b"pipeline_id"]) -> None: ...

global___TriggerNamespacePipelineWithStreamRequest = TriggerNamespacePipelineWithStreamRequest

@typing_extensions.final
class TriggerNamespacePipelineWithStreamResponse(google.protobuf.message.Message):
    """TriggerNamespacePipelineWithStreamResponse contains the pipeline execution results, i.e.,
    the multiple model inference outputs.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUTS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Model inference outputs."""
    @property
    def metadata(self) -> global___TriggerMetadata:
        """Traces of the pipeline inference."""
    def __init__(
        self,
        *,
        outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        metadata: global___TriggerMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "outputs", b"outputs"]) -> None: ...

global___TriggerNamespacePipelineWithStreamResponse = TriggerNamespacePipelineWithStreamResponse

@typing_extensions.final
class TriggerAsyncNamespacePipelineRequest(google.protobuf.message.Message):
    """TriggerNamespacePipelineRequest represents a request to trigger a user-owned
    pipeline synchronously.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Pipeline input parameters, it will be deprecated soon."""
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TriggerData]:
        """Data"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        data: collections.abc.Iterable[global___TriggerData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "inputs", b"inputs", "namespace_id", b"namespace_id", "pipeline_id", b"pipeline_id"]) -> None: ...

global___TriggerAsyncNamespacePipelineRequest = TriggerAsyncNamespacePipelineRequest

@typing_extensions.final
class TriggerAsyncNamespacePipelineResponse(google.protobuf.message.Message):
    """TriggerAsyncNamespacePipelineResponse contains the information to access the
    status of an asynchronous pipeline execution.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATION_FIELD_NUMBER: builtins.int
    @property
    def operation(self) -> google.longrunning.operations_pb2.Operation:
        """Long-running operation information."""
    def __init__(
        self,
        *,
        operation: google.longrunning.operations_pb2.Operation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["operation", b"operation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["operation", b"operation"]) -> None: ...

global___TriggerAsyncNamespacePipelineResponse = TriggerAsyncNamespacePipelineResponse

@typing_extensions.final
class CreateNamespacePipelineReleaseRequest(google.protobuf.message.Message):
    """CreateNamespacePipelineReleaseRequest represents a request to release a version
    in a user-owned pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    RELEASE_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    @property
    def release(self) -> global___PipelineRelease:
        """The release information."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        release: global___PipelineRelease | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespace_id", b"namespace_id", "pipeline_id", b"pipeline_id", "release", b"release"]) -> None: ...

global___CreateNamespacePipelineReleaseRequest = CreateNamespacePipelineReleaseRequest

@typing_extensions.final
class CreateNamespacePipelineReleaseResponse(google.protobuf.message.Message):
    """CreateNamespacePipelineReleaseResponse contains the created release."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> global___PipelineRelease:
        """The created pipeline release object."""
    def __init__(
        self,
        *,
        release: global___PipelineRelease | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release", b"release"]) -> None: ...

global___CreateNamespacePipelineReleaseResponse = CreateNamespacePipelineReleaseResponse

@typing_extensions.final
class ListNamespacePipelineReleasesRequest(google.protobuf.message.Message):
    """ListNamespacePipelineReleasesRequest represents a request to list the releases in
    a user-owned pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    SHOW_DELETED_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    page_size: builtins.int
    """The maximum number of releases to return. If this parameter is
    unspecified, at most 10 pipelines will be returned. The cap value for this
    parameter is 100 (i.e. any value above that will be coerced to 100).
    """
    page_token: builtins.str
    """Page token."""
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired pipeline view in the response."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    show_deleted: builtins.bool
    """Include soft-deleted pipelines in the result."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        view: global___Pipeline.View.ValueType | None = ...,
        filter: builtins.str | None = ...,
        show_deleted: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "namespace_id", b"namespace_id", "page_size", b"page_size", "page_token", b"page_token", "pipeline_id", b"pipeline_id", "show_deleted", b"show_deleted", "view", b"view"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_show_deleted", b"_show_deleted"]) -> typing_extensions.Literal["show_deleted"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___ListNamespacePipelineReleasesRequest = ListNamespacePipelineReleasesRequest

@typing_extensions.final
class ListNamespacePipelineReleasesResponse(google.protobuf.message.Message):
    """ListNamespacePipelineReleasesResponse contains a list of pipeline releases."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def releases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineRelease]:
        """A list of pipeline release resources."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of pipeline releases."""
    def __init__(
        self,
        *,
        releases: collections.abc.Iterable[global___PipelineRelease] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "releases", b"releases", "total_size", b"total_size"]) -> None: ...

global___ListNamespacePipelineReleasesResponse = ListNamespacePipelineReleasesResponse

@typing_extensions.final
class GetNamespacePipelineReleaseRequest(google.protobuf.message.Message):
    """GetNamespacePipelineReleaseRequest represents a request to fetchthe details of a
    release in a user-owned pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    RELEASE_ID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    release_id: builtins.str
    """Release ID"""
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired pipeline view in the response."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        release_id: builtins.str = ...,
        view: global___Pipeline.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "namespace_id", b"namespace_id", "pipeline_id", b"pipeline_id", "release_id", b"release_id", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___GetNamespacePipelineReleaseRequest = GetNamespacePipelineReleaseRequest

@typing_extensions.final
class GetNamespacePipelineReleaseResponse(google.protobuf.message.Message):
    """GetNamespacePipelineReleaseResponse contains the requested pipeline release."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> global___PipelineRelease:
        """The pipeline release resource."""
    def __init__(
        self,
        *,
        release: global___PipelineRelease | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release", b"release"]) -> None: ...

global___GetNamespacePipelineReleaseResponse = GetNamespacePipelineReleaseResponse

@typing_extensions.final
class UpdateNamespacePipelineReleaseRequest(google.protobuf.message.Message):
    """UpdateNamespacePipelineReleaseRequest represents a request to update a user-owned
    pipeline release.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    RELEASE_ID_FIELD_NUMBER: builtins.int
    RELEASE_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    release_id: builtins.str
    """Release ID"""
    @property
    def release(self) -> global___PipelineRelease:
        """The pipeline release fields that will replace the existing ones.
        A pipeline release resource to update
        """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """The update mask specifies the subset of fields that should be modified.

        For more information about this field, see
        https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#field-mask.
        """
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        release_id: builtins.str = ...,
        release: global___PipelineRelease | None = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespace_id", b"namespace_id", "pipeline_id", b"pipeline_id", "release", b"release", "release_id", b"release_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateNamespacePipelineReleaseRequest = UpdateNamespacePipelineReleaseRequest

@typing_extensions.final
class UpdateNamespacePipelineReleaseResponse(google.protobuf.message.Message):
    """UpdateNamespacePipelineReleaseResponse contains the updated pipeline release."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> global___PipelineRelease:
        """The updated pipeline release resource."""
    def __init__(
        self,
        *,
        release: global___PipelineRelease | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release", b"release"]) -> None: ...

global___UpdateNamespacePipelineReleaseResponse = UpdateNamespacePipelineReleaseResponse

@typing_extensions.final
class DeleteNamespacePipelineReleaseRequest(google.protobuf.message.Message):
    """DeleteNamespacePipelineReleaseRequest represents a request to delete a release in
    a user-owned pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    RELEASE_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    release_id: builtins.str
    """Release ID"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        release_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespace_id", b"namespace_id", "pipeline_id", b"pipeline_id", "release_id", b"release_id"]) -> None: ...

global___DeleteNamespacePipelineReleaseRequest = DeleteNamespacePipelineReleaseRequest

@typing_extensions.final
class DeleteNamespacePipelineReleaseResponse(google.protobuf.message.Message):
    """DeleteNamespacePipelineReleaseResponse is an empty response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteNamespacePipelineReleaseResponse = DeleteNamespacePipelineReleaseResponse

@typing_extensions.final
class TriggerNamespacePipelineReleaseRequest(google.protobuf.message.Message):
    """TriggerNamespacePipelineReleaseRequest represents a request to trigger a pinned
    release of a user-owned pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    RELEASE_ID_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    release_id: builtins.str
    """Release ID"""
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Pipeline input parameters, it will be deprecated soon."""
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TriggerData]:
        """Data"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        release_id: builtins.str = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        data: collections.abc.Iterable[global___TriggerData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "inputs", b"inputs", "namespace_id", b"namespace_id", "pipeline_id", b"pipeline_id", "release_id", b"release_id"]) -> None: ...

global___TriggerNamespacePipelineReleaseRequest = TriggerNamespacePipelineReleaseRequest

@typing_extensions.final
class TriggerNamespacePipelineReleaseResponse(google.protobuf.message.Message):
    """TriggerNamespacePipelineReleaseResponse contains the pipeline execution results,
    i.e., the multiple model inference outputs.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUTS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Model inference outputs."""
    @property
    def metadata(self) -> global___TriggerMetadata:
        """Traces of the pipeline inference."""
    def __init__(
        self,
        *,
        outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        metadata: global___TriggerMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "outputs", b"outputs"]) -> None: ...

global___TriggerNamespacePipelineReleaseResponse = TriggerNamespacePipelineReleaseResponse

@typing_extensions.final
class TriggerAsyncNamespacePipelineReleaseRequest(google.protobuf.message.Message):
    """TriggerNamespacePipelineReleaseRequest represents a request to trigger a pinned
    release of a user-owned pipeline asynchronously.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    RELEASE_ID_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID"""
    pipeline_id: builtins.str
    """Pipeline ID"""
    release_id: builtins.str
    """Release ID"""
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Pipeline input parameters, it will be deprecated soon."""
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TriggerData]:
        """Data"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        release_id: builtins.str = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        data: collections.abc.Iterable[global___TriggerData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "inputs", b"inputs", "namespace_id", b"namespace_id", "pipeline_id", b"pipeline_id", "release_id", b"release_id"]) -> None: ...

global___TriggerAsyncNamespacePipelineReleaseRequest = TriggerAsyncNamespacePipelineReleaseRequest

@typing_extensions.final
class TriggerAsyncNamespacePipelineReleaseResponse(google.protobuf.message.Message):
    """TriggerAsyncNamespacePipelineReleaseResponse contains the information to access
    the status of an asynchronous pipeline execution.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATION_FIELD_NUMBER: builtins.int
    @property
    def operation(self) -> google.longrunning.operations_pb2.Operation:
        """Long-running operation information."""
    def __init__(
        self,
        *,
        operation: google.longrunning.operations_pb2.Operation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["operation", b"operation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["operation", b"operation"]) -> None: ...

global___TriggerAsyncNamespacePipelineReleaseResponse = TriggerAsyncNamespacePipelineReleaseResponse

@typing_extensions.final
class CreateUserPipelineRequest(google.protobuf.message.Message):
    """CreateUserPipelineRequest represents a request from a user to create a
    pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The properties of the pipeline to be created."""
    parent: builtins.str
    """The parent resource, i.e., the user that creates the pipeline.
    - Format: `users/{user.id}`.
    """
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
        parent: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["parent", b"parent", "pipeline", b"pipeline"]) -> None: ...

global___CreateUserPipelineRequest = CreateUserPipelineRequest

@typing_extensions.final
class CreateUserPipelineResponse(google.protobuf.message.Message):
    """CreateUserPipelineResponse contains the created pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The created pipeline resource."""
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> None: ...

global___CreateUserPipelineResponse = CreateUserPipelineResponse

@typing_extensions.final
class ListUserPipelinesRequest(google.protobuf.message.Message):
    """ListUserPipelinesRequest represents a request to list the pipelines of a
    user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    SHOW_DELETED_FIELD_NUMBER: builtins.int
    VISIBILITY_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of pipelines to return. If this parameter is
    unspecified, at most 10 pipelines will be returned. The cap value for this
    parameter is 100 (i.e. any value above that will be coerced to 100).
    """
    page_token: builtins.str
    """Page token."""
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired pipeline view in the response."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    - Example:
    `recipe.components.definition_name:"operator-definitions/2ac8be70-0f7a-4b61-a33d-098b8acfa6f3"`.
    """
    parent: builtins.str
    """The parent resource, i.e., the user that created the pipelines.
    - Format: `users/{user.id}`.
    """
    show_deleted: builtins.bool
    """Include soft-deleted pipelines in the result."""
    visibility: global___Pipeline.Visibility.ValueType
    """Limit results to pipelines with the specified visibility."""
    order_by: builtins.str
    """Order by field, with options for ordering by `id`, `create_time` or `update_time`.
    Format: `order_by=id` or `order_by=create_time desc`, default is `asc`.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        view: global___Pipeline.View.ValueType | None = ...,
        filter: builtins.str | None = ...,
        parent: builtins.str = ...,
        show_deleted: builtins.bool | None = ...,
        visibility: global___Pipeline.Visibility.ValueType | None = ...,
        order_by: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_order_by", b"_order_by", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "_visibility", b"_visibility", "filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view", "visibility", b"visibility"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_order_by", b"_order_by", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "_visibility", b"_visibility", "filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token", "parent", b"parent", "show_deleted", b"show_deleted", "view", b"view", "visibility", b"visibility"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_order_by", b"_order_by"]) -> typing_extensions.Literal["order_by"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_show_deleted", b"_show_deleted"]) -> typing_extensions.Literal["show_deleted"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_visibility", b"_visibility"]) -> typing_extensions.Literal["visibility"] | None: ...

global___ListUserPipelinesRequest = ListUserPipelinesRequest

@typing_extensions.final
class ListUserPipelinesResponse(google.protobuf.message.Message):
    """ListUserPipelinesResponse contains a list of pipelines."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def pipelines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Pipeline]:
        """A list of pipeline resources."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of pipelines."""
    def __init__(
        self,
        *,
        pipelines: collections.abc.Iterable[global___Pipeline] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "pipelines", b"pipelines", "total_size", b"total_size"]) -> None: ...

global___ListUserPipelinesResponse = ListUserPipelinesResponse

@typing_extensions.final
class GetUserPipelineRequest(google.protobuf.message.Message):
    """GetUserPipelineRequest represents a request to fetch the details of a
    pipeline owned by a user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline, which allows its access by parent user
    and ID.
    - Format: `users/{user.id}/pipelines/{pipeline.id}`.
    """
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired pipeline view in the response."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        view: global___Pipeline.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "name", b"name", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___GetUserPipelineRequest = GetUserPipelineRequest

@typing_extensions.final
class GetUserPipelineResponse(google.protobuf.message.Message):
    """GetUserPipelineResponse contains the requested pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The pipeline resource."""
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> None: ...

global___GetUserPipelineResponse = GetUserPipelineResponse

@typing_extensions.final
class UpdateUserPipelineRequest(google.protobuf.message.Message):
    """UpdateUserPipelineRequest represents a request to update a pipeline owned by
    a user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The pipeline fields that will replace the existing ones."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """The update mask specifies the subset of fields that should be modified.

        For more information about this field, see
        https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#field-mask.
        """
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline", "update_mask", b"update_mask"]) -> None: ...

global___UpdateUserPipelineRequest = UpdateUserPipelineRequest

@typing_extensions.final
class UpdateUserPipelineResponse(google.protobuf.message.Message):
    """UpdateUserPipelineResponse contains the updated pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The updated pipeline resource."""
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> None: ...

global___UpdateUserPipelineResponse = UpdateUserPipelineResponse

@typing_extensions.final
class DeleteUserPipelineRequest(google.protobuf.message.Message):
    """DeleteUserPipelineRequest represents a request to delete a pipeline owned by
    a user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline, which allows its access by parent user
    and ID.
    - Format: `users/{user.id}/pipelines/{pipeline.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeleteUserPipelineRequest = DeleteUserPipelineRequest

@typing_extensions.final
class DeleteUserPipelineResponse(google.protobuf.message.Message):
    """DeleteUserPipelineResponse is an empty response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteUserPipelineResponse = DeleteUserPipelineResponse

@typing_extensions.final
class ErrPipelineValidation(google.protobuf.message.Message):
    """ErrPipelineValidation contains information about a failed pipeline
    validation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCATION_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    location: builtins.str
    """Location"""
    error: builtins.str
    """error"""
    def __init__(
        self,
        *,
        location: builtins.str = ...,
        error: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["error", b"error", "location", b"location"]) -> None: ...

global___ErrPipelineValidation = ErrPipelineValidation

@typing_extensions.final
class ValidateUserPipelineRequest(google.protobuf.message.Message):
    """ValidateUserPipelineRequest represents a request to validate a pipeline
    owned by a user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline, which allows its access by parent user
    and ID.
    - Format: `users/{user.id}/pipelines/{pipeline.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___ValidateUserPipelineRequest = ValidateUserPipelineRequest

@typing_extensions.final
class ValidateUserPipelineResponse(google.protobuf.message.Message):
    """ValidateUserPipelineResponse contains a validated pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    ERRORS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    """Success"""
    @property
    def errors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ErrPipelineValidation]:
        """The validated pipeline resource."""
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
        errors: collections.abc.Iterable[global___ErrPipelineValidation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["errors", b"errors", "success", b"success"]) -> None: ...

global___ValidateUserPipelineResponse = ValidateUserPipelineResponse

@typing_extensions.final
class RenameUserPipelineRequest(google.protobuf.message.Message):
    """RenameUserPipelineRequest represents a request to rename the name of a
    pipeline owned by a user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    NEW_PIPELINE_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline, which allows its access by parent user
    and ID.
    - Format: `users/{user.id}/pipelines/{pipeline.id}`.
    """
    new_pipeline_id: builtins.str
    """The new resource ID. This will transform the resource name into
    `users/{user.id}/pipelines/{new_pipeline_id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        new_pipeline_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "new_pipeline_id", b"new_pipeline_id"]) -> None: ...

global___RenameUserPipelineRequest = RenameUserPipelineRequest

@typing_extensions.final
class RenameUserPipelineResponse(google.protobuf.message.Message):
    """RenameUserPipelineResponse contains a renamed pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The renamed pipeline resource."""
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> None: ...

global___RenameUserPipelineResponse = RenameUserPipelineResponse

@typing_extensions.final
class TriggerUserPipelineRequest(google.protobuf.message.Message):
    """TriggerUserPipelineRequest represents a request to trigger a user-owned
    pipeline synchronously.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline, which allows its access by parent user
    and ID.
    - Format: `users/{user.id}/pipelines/{pipeline.id}`.
    """
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Pipeline input parameters, it will be deprecated soon."""
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TriggerData]:
        """Data"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        data: collections.abc.Iterable[global___TriggerData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "inputs", b"inputs", "name", b"name"]) -> None: ...

global___TriggerUserPipelineRequest = TriggerUserPipelineRequest

@typing_extensions.final
class TriggerUserPipelineResponse(google.protobuf.message.Message):
    """TriggerUserPipelineResponse contains the pipeline execution results, i.e.,
    the multiple model inference outputs.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUTS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Model inference outputs."""
    @property
    def metadata(self) -> global___TriggerMetadata:
        """Traces of the pipeline inference."""
    def __init__(
        self,
        *,
        outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        metadata: global___TriggerMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "outputs", b"outputs"]) -> None: ...

global___TriggerUserPipelineResponse = TriggerUserPipelineResponse

@typing_extensions.final
class TriggerUserPipelineWithStreamRequest(google.protobuf.message.Message):
    """TriggerUserPipelineWithStreamRequest represents a request to trigger a user-owned
    pipeline synchronously and streams back the results.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline, which allows its access by parent user
    and ID.
    - Format: `users/{user.id}/pipelines/{pipeline.id}`.
    """
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Pipeline input parameters, it will be deprecated soon."""
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TriggerData]:
        """Data"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        data: collections.abc.Iterable[global___TriggerData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "inputs", b"inputs", "name", b"name"]) -> None: ...

global___TriggerUserPipelineWithStreamRequest = TriggerUserPipelineWithStreamRequest

@typing_extensions.final
class TriggerUserPipelineWithStreamResponse(google.protobuf.message.Message):
    """TriggerUserPipelineWithStreamResponse contains the pipeline execution results, i.e.,
    the multiple model inference outputs.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUTS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Model inference outputs."""
    @property
    def metadata(self) -> global___TriggerMetadata:
        """Traces of the pipeline inference."""
    def __init__(
        self,
        *,
        outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        metadata: global___TriggerMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "outputs", b"outputs"]) -> None: ...

global___TriggerUserPipelineWithStreamResponse = TriggerUserPipelineWithStreamResponse

@typing_extensions.final
class TriggerData(google.protobuf.message.Message):
    """Data"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SecretEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    VARIABLE_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    @property
    def variable(self) -> google.protobuf.struct_pb2.Struct:
        """Variables"""
    @property
    def secret(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Variables"""
    def __init__(
        self,
        *,
        variable: google.protobuf.struct_pb2.Struct | None = ...,
        secret: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["variable", b"variable"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret", b"secret", "variable", b"variable"]) -> None: ...

global___TriggerData = TriggerData

@typing_extensions.final
class TriggerAsyncUserPipelineRequest(google.protobuf.message.Message):
    """TriggerUserPipelineRequest represents a request to trigger a user-owned
    pipeline synchronously.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline, which allows its access by parent user
    and ID.
    - Format: `users/{user.id}/pipelines/{pipeline.id}`.
    """
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Pipeline input parameters, it will be deprecated soon."""
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TriggerData]:
        """Data"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        data: collections.abc.Iterable[global___TriggerData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "inputs", b"inputs", "name", b"name"]) -> None: ...

global___TriggerAsyncUserPipelineRequest = TriggerAsyncUserPipelineRequest

@typing_extensions.final
class TriggerAsyncUserPipelineResponse(google.protobuf.message.Message):
    """TriggerAsyncUserPipelineResponse contains the information to access the
    status of an asynchronous pipeline execution.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATION_FIELD_NUMBER: builtins.int
    @property
    def operation(self) -> google.longrunning.operations_pb2.Operation:
        """Long-running operation information."""
    def __init__(
        self,
        *,
        operation: google.longrunning.operations_pb2.Operation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["operation", b"operation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["operation", b"operation"]) -> None: ...

global___TriggerAsyncUserPipelineResponse = TriggerAsyncUserPipelineResponse

@typing_extensions.final
class CreateUserPipelineReleaseRequest(google.protobuf.message.Message):
    """CreateUserPipelineReleaseRequest represents a request to release a version
    in a user-owned pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> global___PipelineRelease:
        """The release information."""
    parent: builtins.str
    """Name of the pipeline for which the release will be created.
    Format: `users/{user.id}/pipelines/{pipeline.id}`
    """
    def __init__(
        self,
        *,
        release: global___PipelineRelease | None = ...,
        parent: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["parent", b"parent", "release", b"release"]) -> None: ...

global___CreateUserPipelineReleaseRequest = CreateUserPipelineReleaseRequest

@typing_extensions.final
class CreateUserPipelineReleaseResponse(google.protobuf.message.Message):
    """CreateUserPipelineReleaseResponse contains the created release."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> global___PipelineRelease:
        """The created pipeline release object."""
    def __init__(
        self,
        *,
        release: global___PipelineRelease | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release", b"release"]) -> None: ...

global___CreateUserPipelineReleaseResponse = CreateUserPipelineReleaseResponse

@typing_extensions.final
class ListUserPipelineReleasesRequest(google.protobuf.message.Message):
    """ListUserPipelineReleasesRequest represents a request to list the releases in
    a user-owned pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    SHOW_DELETED_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of releases to return. If this parameter is
    unspecified, at most 10 pipelines will be returned. The cap value for this
    parameter is 100 (i.e. any value above that will be coerced to 100).
    """
    page_token: builtins.str
    """Page token."""
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired pipeline view in the response."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    parent: builtins.str
    """The parent resource where this pipeline release will be created.
    Format: `users/{user.id}/pipelines/{pipeline.id}`.
    """
    show_deleted: builtins.bool
    """Include soft-deleted pipelines in the result."""
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        view: global___Pipeline.View.ValueType | None = ...,
        filter: builtins.str | None = ...,
        parent: builtins.str = ...,
        show_deleted: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "parent", b"parent", "show_deleted", b"show_deleted", "view", b"view"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_show_deleted", b"_show_deleted"]) -> typing_extensions.Literal["show_deleted"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___ListUserPipelineReleasesRequest = ListUserPipelineReleasesRequest

@typing_extensions.final
class ListUserPipelineReleasesResponse(google.protobuf.message.Message):
    """ListUserPipelineReleasesResponse contains a list of pipeline releases."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def releases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineRelease]:
        """A list of pipeline release resources."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of pipeline releases."""
    def __init__(
        self,
        *,
        releases: collections.abc.Iterable[global___PipelineRelease] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "releases", b"releases", "total_size", b"total_size"]) -> None: ...

global___ListUserPipelineReleasesResponse = ListUserPipelineReleasesResponse

@typing_extensions.final
class GetUserPipelineReleaseRequest(google.protobuf.message.Message):
    """GetUserPipelineReleaseRequest represents a request to fetchthe details of a
    release in a user-owned pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline release, which allows its access by
    parent pipeline and ID.
    - Format: `users/{user.id}/pipelines/{pipeline.id}/releases/{release.id}`.
    """
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired pipeline view in the response."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        view: global___Pipeline.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "name", b"name", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___GetUserPipelineReleaseRequest = GetUserPipelineReleaseRequest

@typing_extensions.final
class GetUserPipelineReleaseResponse(google.protobuf.message.Message):
    """GetUserPipelineReleaseResponse contains the requested pipeline release."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> global___PipelineRelease:
        """The pipeline release resource."""
    def __init__(
        self,
        *,
        release: global___PipelineRelease | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release", b"release"]) -> None: ...

global___GetUserPipelineReleaseResponse = GetUserPipelineReleaseResponse

@typing_extensions.final
class UpdateUserPipelineReleaseRequest(google.protobuf.message.Message):
    """UpdateUserPipelineReleaseRequest represents a request to update a user-owned
    pipeline release.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> global___PipelineRelease:
        """The pipeline release fields that will replace the existing ones.
        A pipeline release resource to update
        """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """The update mask specifies the subset of fields that should be modified.

        For more information about this field, see
        https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#field-mask.
        """
    def __init__(
        self,
        *,
        release: global___PipelineRelease | None = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release", b"release", "update_mask", b"update_mask"]) -> None: ...

global___UpdateUserPipelineReleaseRequest = UpdateUserPipelineReleaseRequest

@typing_extensions.final
class UpdateUserPipelineReleaseResponse(google.protobuf.message.Message):
    """UpdateUserPipelineReleaseResponse contains the updated pipeline release."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> global___PipelineRelease:
        """The updated pipeline release resource."""
    def __init__(
        self,
        *,
        release: global___PipelineRelease | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release", b"release"]) -> None: ...

global___UpdateUserPipelineReleaseResponse = UpdateUserPipelineReleaseResponse

@typing_extensions.final
class DeleteUserPipelineReleaseRequest(google.protobuf.message.Message):
    """DeleteUserPipelineReleaseRequest represents a request to delete a release in
    a user-owned pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline release, which allows its access by
    parent pipeline and ID.
    - Format: `users/{user.id}/pipelines/{pipeline.id}/releases/{release.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeleteUserPipelineReleaseRequest = DeleteUserPipelineReleaseRequest

@typing_extensions.final
class DeleteUserPipelineReleaseResponse(google.protobuf.message.Message):
    """DeleteUserPipelineReleaseResponse is an empty response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteUserPipelineReleaseResponse = DeleteUserPipelineReleaseResponse

@typing_extensions.final
class RestoreUserPipelineReleaseRequest(google.protobuf.message.Message):
    """RestoreUserPipelineReleaseRequest represents a request to set the version of
    a user-owned pipeline to a pinned release.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline release, which allows its access by
    parent pipeline and ID.
    - Format: `users/{user.id}/pipelines/{pipeline.id}/releases/{release.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___RestoreUserPipelineReleaseRequest = RestoreUserPipelineReleaseRequest

@typing_extensions.final
class RestoreUserPipelineReleaseResponse(google.protobuf.message.Message):
    """RestoreUserPipelineReleaseResponse contains the requested pipeline release."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> global___PipelineRelease:
        """The pipeline release resource."""
    def __init__(
        self,
        *,
        release: global___PipelineRelease | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release", b"release"]) -> None: ...

global___RestoreUserPipelineReleaseResponse = RestoreUserPipelineReleaseResponse

@typing_extensions.final
class RenameUserPipelineReleaseRequest(google.protobuf.message.Message):
    """RenameUserPipelineReleaseRequest represents a request to rename a release in
    a user-owned pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    NEW_PIPELINE_RELEASE_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline release, which allows its access by
    parent pipeline and ID.
    - Format: `users/{user.id}/pipelines/{pipeline.id}/releases/{release.id}`.
    """
    new_pipeline_release_id: builtins.str
    """The new resource ID. This will transform the resource name into
    `users/{user.id}/pipelines/{pipeline.id}/releases{new_release_id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        new_pipeline_release_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "new_pipeline_release_id", b"new_pipeline_release_id"]) -> None: ...

global___RenameUserPipelineReleaseRequest = RenameUserPipelineReleaseRequest

@typing_extensions.final
class RenameUserPipelineReleaseResponse(google.protobuf.message.Message):
    """RenameUserPipelineReleaseResponse contains a renamed pipeline release."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> global___PipelineRelease:
        """The renamed pipeline release."""
    def __init__(
        self,
        *,
        release: global___PipelineRelease | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release", b"release"]) -> None: ...

global___RenameUserPipelineReleaseResponse = RenameUserPipelineReleaseResponse

@typing_extensions.final
class TriggerUserPipelineReleaseRequest(google.protobuf.message.Message):
    """TriggerUserPipelineReleaseRequest represents a request to trigger a pinned
    release of a user-owned pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline release, which allows its access by
    parent pipeline and ID.
    - Format: `users/{user.id}/pipelines/{pipeline.id}/releases/{release.id}`.
    """
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Pipeline input parameters, it will be deprecated soon."""
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TriggerData]:
        """Data"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        data: collections.abc.Iterable[global___TriggerData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "inputs", b"inputs", "name", b"name"]) -> None: ...

global___TriggerUserPipelineReleaseRequest = TriggerUserPipelineReleaseRequest

@typing_extensions.final
class TriggerUserPipelineReleaseResponse(google.protobuf.message.Message):
    """TriggerUserPipelineReleaseResponse contains the pipeline execution results,
    i.e., the multiple model inference outputs.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUTS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Model inference outputs."""
    @property
    def metadata(self) -> global___TriggerMetadata:
        """Traces of the pipeline inference."""
    def __init__(
        self,
        *,
        outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        metadata: global___TriggerMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "outputs", b"outputs"]) -> None: ...

global___TriggerUserPipelineReleaseResponse = TriggerUserPipelineReleaseResponse

@typing_extensions.final
class TriggerAsyncUserPipelineReleaseRequest(google.protobuf.message.Message):
    """TriggerUserPipelineReleaseRequest represents a request to trigger a pinned
    release of a user-owned pipeline asynchronously.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline release, which allows its access by
    parent pipeline and ID.
    - Format: `users/{user.id}/pipelines/{pipeline.id}/releases/{release.id}`.
    """
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Pipeline input parameters, it will be deprecated soon."""
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TriggerData]:
        """Data"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        data: collections.abc.Iterable[global___TriggerData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "inputs", b"inputs", "name", b"name"]) -> None: ...

global___TriggerAsyncUserPipelineReleaseRequest = TriggerAsyncUserPipelineReleaseRequest

@typing_extensions.final
class TriggerAsyncUserPipelineReleaseResponse(google.protobuf.message.Message):
    """TriggerAsyncUserPipelineReleaseResponse contains the information to access
    the status of an asynchronous pipeline execution.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATION_FIELD_NUMBER: builtins.int
    @property
    def operation(self) -> google.longrunning.operations_pb2.Operation:
        """Long-running operation information."""
    def __init__(
        self,
        *,
        operation: google.longrunning.operations_pb2.Operation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["operation", b"operation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["operation", b"operation"]) -> None: ...

global___TriggerAsyncUserPipelineReleaseResponse = TriggerAsyncUserPipelineReleaseResponse

@typing_extensions.final
class CreateOrganizationPipelineRequest(google.protobuf.message.Message):
    """CreateOrganizationPipelineRequest represents a request from an organization
    to create a pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The properties of the pipeline to be created."""
    parent: builtins.str
    """The parent resource, i.e., the organization that creates the pipeline.
    - Format: `organizations/{organization.id}`.
    """
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
        parent: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["parent", b"parent", "pipeline", b"pipeline"]) -> None: ...

global___CreateOrganizationPipelineRequest = CreateOrganizationPipelineRequest

@typing_extensions.final
class CreateOrganizationPipelineResponse(google.protobuf.message.Message):
    """CreateOrganizationPipelineResponse contains the created pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The created pipeline resource."""
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> None: ...

global___CreateOrganizationPipelineResponse = CreateOrganizationPipelineResponse

@typing_extensions.final
class ListOrganizationPipelinesRequest(google.protobuf.message.Message):
    """ListOrganizationPipelinesRequest represents a request to list the pipelines
    of an organization.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    SHOW_DELETED_FIELD_NUMBER: builtins.int
    VISIBILITY_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of pipelines to return. If this parameter is
    unspecified, at most 10 pipelines will be returned. The cap value for this
    parameter is 100 (i.e. any value above that will be coerced to 100).
    """
    page_token: builtins.str
    """Page token."""
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired pipeline view in the response."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    - Example:
    `recipe.components.definition_name:"operator-definitions/2ac8be70-0f7a-4b61-a33d-098b8acfa6f3"`.
    """
    parent: builtins.str
    """The parent resource, i.e., the organization that created the pipelines.
    - Format: `organizations/{organization.id}`.
    """
    show_deleted: builtins.bool
    """Include soft-deleted pipelines in the result."""
    visibility: global___Pipeline.Visibility.ValueType
    """Limit results to pipelines with the specified visibility."""
    order_by: builtins.str
    """Order by field, with options for ordering by `id`, `create_time` or `update_time`.
    Format: `order_by=id` or `order_by=create_time desc`, default is `asc`.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        view: global___Pipeline.View.ValueType | None = ...,
        filter: builtins.str | None = ...,
        parent: builtins.str = ...,
        show_deleted: builtins.bool | None = ...,
        visibility: global___Pipeline.Visibility.ValueType | None = ...,
        order_by: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_order_by", b"_order_by", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "_visibility", b"_visibility", "filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view", "visibility", b"visibility"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_order_by", b"_order_by", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "_visibility", b"_visibility", "filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token", "parent", b"parent", "show_deleted", b"show_deleted", "view", b"view", "visibility", b"visibility"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_order_by", b"_order_by"]) -> typing_extensions.Literal["order_by"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_show_deleted", b"_show_deleted"]) -> typing_extensions.Literal["show_deleted"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_visibility", b"_visibility"]) -> typing_extensions.Literal["visibility"] | None: ...

global___ListOrganizationPipelinesRequest = ListOrganizationPipelinesRequest

@typing_extensions.final
class ListOrganizationPipelinesResponse(google.protobuf.message.Message):
    """ListOrganizationPipelinesResponse contains a list of pipelines."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def pipelines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Pipeline]:
        """A list of pipeline resources."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of pipelines."""
    def __init__(
        self,
        *,
        pipelines: collections.abc.Iterable[global___Pipeline] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "pipelines", b"pipelines", "total_size", b"total_size"]) -> None: ...

global___ListOrganizationPipelinesResponse = ListOrganizationPipelinesResponse

@typing_extensions.final
class GetOrganizationPipelineRequest(google.protobuf.message.Message):
    """GetOrganizationPipelineRequest represents a request to fetch the details of
    a pipeline owned by an organization.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline, which allows its access by parent
    organization and ID.
    - Format: `organizations/{organization.id}/pipelines/{pipeline.id}`.
    """
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired pipeline view in the response."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        view: global___Pipeline.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "name", b"name", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___GetOrganizationPipelineRequest = GetOrganizationPipelineRequest

@typing_extensions.final
class GetOrganizationPipelineResponse(google.protobuf.message.Message):
    """GetOrganizationPipelineResponse contains the requested pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The pipeline resource."""
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> None: ...

global___GetOrganizationPipelineResponse = GetOrganizationPipelineResponse

@typing_extensions.final
class UpdateOrganizationPipelineRequest(google.protobuf.message.Message):
    """UpdateOrganizationPipelineRequest represents a request to update a pipeline
    owned by an organization.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The pipeline fields that will replace the existing ones."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """The update mask specifies the subset of fields that should be modified.

        For more information about this field, see
        https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#field-mask.
        """
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline", "update_mask", b"update_mask"]) -> None: ...

global___UpdateOrganizationPipelineRequest = UpdateOrganizationPipelineRequest

@typing_extensions.final
class UpdateOrganizationPipelineResponse(google.protobuf.message.Message):
    """UpdateOrganizationPipelineResponse contains the updated pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The updated pipeline resource."""
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> None: ...

global___UpdateOrganizationPipelineResponse = UpdateOrganizationPipelineResponse

@typing_extensions.final
class DeleteOrganizationPipelineRequest(google.protobuf.message.Message):
    """DeleteOrganizationPipelineRequest represents a request to delete a pipeline
    owned by an organization.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline, which allows its access by parent
    organization and ID.
    - Format: `organizations/{organization.id}/pipelines/{pipeline.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeleteOrganizationPipelineRequest = DeleteOrganizationPipelineRequest

@typing_extensions.final
class DeleteOrganizationPipelineResponse(google.protobuf.message.Message):
    """DeleteOrganizationPipelineResponse is an empty response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteOrganizationPipelineResponse = DeleteOrganizationPipelineResponse

@typing_extensions.final
class ValidateOrganizationPipelineRequest(google.protobuf.message.Message):
    """ValidateOrganizationPipelineRequest represents a request to validate a
    pipeline owned by an organization.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline, which allows its access by parent
    organization and ID.
    - Format: `organizations/{organization.id}/pipelines/{pipeline.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___ValidateOrganizationPipelineRequest = ValidateOrganizationPipelineRequest

@typing_extensions.final
class ValidateOrganizationPipelineResponse(google.protobuf.message.Message):
    """ValidateOrganizationPipelineResponse contains a validated pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    ERRORS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    """Success"""
    @property
    def errors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ErrPipelineValidation]:
        """The validated pipeline resource."""
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
        errors: collections.abc.Iterable[global___ErrPipelineValidation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["errors", b"errors", "success", b"success"]) -> None: ...

global___ValidateOrganizationPipelineResponse = ValidateOrganizationPipelineResponse

@typing_extensions.final
class RenameOrganizationPipelineRequest(google.protobuf.message.Message):
    """RenameOrganizationPipelineRequest represents a request to rename the name of
    a pipeline owned by an organization.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    NEW_PIPELINE_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline, which allows its access by parent
    organization and ID.
    - Format: `organizations/{organization.id}/pipelines/{pipeline.id}`.
    """
    new_pipeline_id: builtins.str
    """The new resource ID. This will transform the resource name into
    `organizations/{organization.id}/pipelines/{new_pipeline_id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        new_pipeline_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "new_pipeline_id", b"new_pipeline_id"]) -> None: ...

global___RenameOrganizationPipelineRequest = RenameOrganizationPipelineRequest

@typing_extensions.final
class RenameOrganizationPipelineResponse(google.protobuf.message.Message):
    """RenameOrganizationPipelineResponse contains a renamed pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The renamed pipeline resource."""
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> None: ...

global___RenameOrganizationPipelineResponse = RenameOrganizationPipelineResponse

@typing_extensions.final
class TriggerOrganizationPipelineRequest(google.protobuf.message.Message):
    """TriggerOrganizationPipelineRequest represents a request to trigger an
    organization-owned pipeline synchronously.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline, which allows its access by parent
    organization and ID.
    - Format: `organizations/{organization.id}/pipelines/{pipeline.id}`.
    """
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Pipeline input parameters, it will be deprecated soon."""
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TriggerData]:
        """Data"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        data: collections.abc.Iterable[global___TriggerData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "inputs", b"inputs", "name", b"name"]) -> None: ...

global___TriggerOrganizationPipelineRequest = TriggerOrganizationPipelineRequest

@typing_extensions.final
class TriggerOrganizationPipelineResponse(google.protobuf.message.Message):
    """TriggerOrganizationPipelineResponse contains the pipeline execution results,
    i.e., the multiple model inference outputs.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUTS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Model inference outputs."""
    @property
    def metadata(self) -> global___TriggerMetadata:
        """Traces of the pipeline inference."""
    def __init__(
        self,
        *,
        outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        metadata: global___TriggerMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "outputs", b"outputs"]) -> None: ...

global___TriggerOrganizationPipelineResponse = TriggerOrganizationPipelineResponse

@typing_extensions.final
class TriggerOrganizationPipelineStreamRequest(google.protobuf.message.Message):
    """TriggerOrganizationPipelineRequest represents a request to trigger an
    organization-owned pipeline synchronously.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline, which allows its access by parent
    organization and ID.
    - Format: `organizations/{organization.id}/pipelines/{pipeline.id}`.
    """
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Pipeline input parameters, it will be deprecated soon."""
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TriggerData]:
        """Data"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        data: collections.abc.Iterable[global___TriggerData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "inputs", b"inputs", "name", b"name"]) -> None: ...

global___TriggerOrganizationPipelineStreamRequest = TriggerOrganizationPipelineStreamRequest

@typing_extensions.final
class TriggerOrganizationPipelineStreamResponse(google.protobuf.message.Message):
    """TriggerOrganizationPipelineResponse contains the pipeline execution results,
    i.e., the multiple model inference outputs.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUTS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Model inference outputs."""
    @property
    def metadata(self) -> global___TriggerMetadata:
        """Traces of the pipeline inference."""
    def __init__(
        self,
        *,
        outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        metadata: global___TriggerMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "outputs", b"outputs"]) -> None: ...

global___TriggerOrganizationPipelineStreamResponse = TriggerOrganizationPipelineStreamResponse

@typing_extensions.final
class TriggerAsyncOrganizationPipelineRequest(google.protobuf.message.Message):
    """TriggerOrganizationPipelineRequest represents a request to trigger an
    organization-owned pipeline synchronously.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline, which allows its access by parent
    organization and ID.
    - Format: `organizations/{organization.id}/pipelines/{pipeline.id}`.
    """
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Pipeline input parameters, it will be deprecated soon."""
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TriggerData]:
        """Data"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        data: collections.abc.Iterable[global___TriggerData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "inputs", b"inputs", "name", b"name"]) -> None: ...

global___TriggerAsyncOrganizationPipelineRequest = TriggerAsyncOrganizationPipelineRequest

@typing_extensions.final
class TriggerAsyncOrganizationPipelineResponse(google.protobuf.message.Message):
    """TriggerAsyncOrganizationPipelineResponse contains the information to access
    the status of an asynchronous pipeline execution.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATION_FIELD_NUMBER: builtins.int
    @property
    def operation(self) -> google.longrunning.operations_pb2.Operation:
        """Long-running operation information."""
    def __init__(
        self,
        *,
        operation: google.longrunning.operations_pb2.Operation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["operation", b"operation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["operation", b"operation"]) -> None: ...

global___TriggerAsyncOrganizationPipelineResponse = TriggerAsyncOrganizationPipelineResponse

@typing_extensions.final
class CreateOrganizationPipelineReleaseRequest(google.protobuf.message.Message):
    """CreateOrganizationPipelineReleaseRequest represents a request to release a
    version in an organization-owned pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> global___PipelineRelease:
        """The release information."""
    parent: builtins.str
    """Name of the pipeline for which the release will be created.
    Format: `organizations/{organization.id}/pipelines/{pipeline.id}`
    """
    def __init__(
        self,
        *,
        release: global___PipelineRelease | None = ...,
        parent: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["parent", b"parent", "release", b"release"]) -> None: ...

global___CreateOrganizationPipelineReleaseRequest = CreateOrganizationPipelineReleaseRequest

@typing_extensions.final
class CreateOrganizationPipelineReleaseResponse(google.protobuf.message.Message):
    """CreateOrganizationPipelineReleaseResponse contains the created release."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> global___PipelineRelease:
        """The created pipeline release object."""
    def __init__(
        self,
        *,
        release: global___PipelineRelease | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release", b"release"]) -> None: ...

global___CreateOrganizationPipelineReleaseResponse = CreateOrganizationPipelineReleaseResponse

@typing_extensions.final
class ListOrganizationPipelineReleasesRequest(google.protobuf.message.Message):
    """ListOrganizationPipelineReleasesRequest represents a request to list the
    releases in an organization-owned pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    SHOW_DELETED_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of releases to return. If this parameter is
    unspecified, at most 10 pipelines will be returned. The cap value for this
    parameter is 100 (i.e. any value above that will be coerced to 100).
    """
    page_token: builtins.str
    """Page token."""
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired pipeline view in the response."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    parent: builtins.str
    """The parent resource where this pipeline release will be created.
    Format: `organizations/{organization.id}/pipelines/{pipeline.id}`
    """
    show_deleted: builtins.bool
    """Include soft-deleted pipelines in the result."""
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        view: global___Pipeline.View.ValueType | None = ...,
        filter: builtins.str | None = ...,
        parent: builtins.str = ...,
        show_deleted: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "parent", b"parent", "show_deleted", b"show_deleted", "view", b"view"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_show_deleted", b"_show_deleted"]) -> typing_extensions.Literal["show_deleted"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___ListOrganizationPipelineReleasesRequest = ListOrganizationPipelineReleasesRequest

@typing_extensions.final
class ListOrganizationPipelineReleasesResponse(google.protobuf.message.Message):
    """ListOrganizationPipelineReleasesResponse contains a list of pipeline releases."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def releases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineRelease]:
        """A list of pipeline release resources."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of pipeline releases."""
    def __init__(
        self,
        *,
        releases: collections.abc.Iterable[global___PipelineRelease] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "releases", b"releases", "total_size", b"total_size"]) -> None: ...

global___ListOrganizationPipelineReleasesResponse = ListOrganizationPipelineReleasesResponse

@typing_extensions.final
class GetOrganizationPipelineReleaseRequest(google.protobuf.message.Message):
    """GetOrganizationPipelineReleaseRequest represents a request to fetchthe
    details of a release in an organization-owned pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline release, which allows its access by
    parent pipeline and ID.
    - Format:
    `organizations/{organization.id}/pipelines/{pipeline.id}/releases/{release.id}`.
    """
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired pipeline view in the response."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        view: global___Pipeline.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "name", b"name", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___GetOrganizationPipelineReleaseRequest = GetOrganizationPipelineReleaseRequest

@typing_extensions.final
class GetOrganizationPipelineReleaseResponse(google.protobuf.message.Message):
    """GetOrganizationPipelineReleaseResponse contains the requested pipeline release."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> global___PipelineRelease:
        """The pipeline release resource."""
    def __init__(
        self,
        *,
        release: global___PipelineRelease | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release", b"release"]) -> None: ...

global___GetOrganizationPipelineReleaseResponse = GetOrganizationPipelineReleaseResponse

@typing_extensions.final
class UpdateOrganizationPipelineReleaseRequest(google.protobuf.message.Message):
    """UpdateOrganizationPipelineReleaseRequest represents a request to update an
    organization-owned pipeline release.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> global___PipelineRelease:
        """The pipeline release fields that will replace the existing ones.
        A pipeline release resource to update
        """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """The update mask specifies the subset of fields that should be modified.

        For more information about this field, see
        https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#field-mask.
        """
    def __init__(
        self,
        *,
        release: global___PipelineRelease | None = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release", b"release", "update_mask", b"update_mask"]) -> None: ...

global___UpdateOrganizationPipelineReleaseRequest = UpdateOrganizationPipelineReleaseRequest

@typing_extensions.final
class UpdateOrganizationPipelineReleaseResponse(google.protobuf.message.Message):
    """UpdateOrganizationPipelineReleaseResponse contains the updated pipeline
    release.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> global___PipelineRelease:
        """The updated pipeline release resource."""
    def __init__(
        self,
        *,
        release: global___PipelineRelease | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release", b"release"]) -> None: ...

global___UpdateOrganizationPipelineReleaseResponse = UpdateOrganizationPipelineReleaseResponse

@typing_extensions.final
class DeleteOrganizationPipelineReleaseRequest(google.protobuf.message.Message):
    """DeleteOrganizationPipelineReleaseRequest represents a request to delete a
    release in an organization-owned pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline release, which allows its access by
    parent pipeline and ID.
    - Format:
    `organizations/{organization.id}/pipelines/{pipeline.id}/releases/{release.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeleteOrganizationPipelineReleaseRequest = DeleteOrganizationPipelineReleaseRequest

@typing_extensions.final
class DeleteOrganizationPipelineReleaseResponse(google.protobuf.message.Message):
    """DeleteOrganizationPipelineReleaseResponse is an empty response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteOrganizationPipelineReleaseResponse = DeleteOrganizationPipelineReleaseResponse

@typing_extensions.final
class RestoreOrganizationPipelineReleaseRequest(google.protobuf.message.Message):
    """RestoreOrganizationPipelineReleaseRequest represents a request to set the
    version of an organization-owned pipeline to a pinned release.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline release, which allows its access by
    parent pipeline and ID.
    - Format:
    `organizations/{organization.id}/pipelines/{pipeline.id}/releases/{release.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___RestoreOrganizationPipelineReleaseRequest = RestoreOrganizationPipelineReleaseRequest

@typing_extensions.final
class RestoreOrganizationPipelineReleaseResponse(google.protobuf.message.Message):
    """RestoreOrganizationPipelineReleaseResponse contains the requested pipeline
    release.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> global___PipelineRelease:
        """The pipeline release resource."""
    def __init__(
        self,
        *,
        release: global___PipelineRelease | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release", b"release"]) -> None: ...

global___RestoreOrganizationPipelineReleaseResponse = RestoreOrganizationPipelineReleaseResponse

@typing_extensions.final
class RenameOrganizationPipelineReleaseRequest(google.protobuf.message.Message):
    """RenameOrganizationPipelineReleaseRequest represents a request to rename a
    release in an organization-owned pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    NEW_PIPELINE_RELEASE_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline release, which allows its access by
    parent pipeline and ID.
    - Format:
    `organizations/{organization.id}/pipelines/{pipeline.id}/releases/{release.id}`.
    """
    new_pipeline_release_id: builtins.str
    """The new resource ID. This will transform the resource name into
    `organizations/{organization.id}/pipelines/{pipeline.id}/releases{new_release_id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        new_pipeline_release_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "new_pipeline_release_id", b"new_pipeline_release_id"]) -> None: ...

global___RenameOrganizationPipelineReleaseRequest = RenameOrganizationPipelineReleaseRequest

@typing_extensions.final
class RenameOrganizationPipelineReleaseResponse(google.protobuf.message.Message):
    """RenameOrganizationPipelineReleaseResponse contains a renamed pipeline release."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> global___PipelineRelease:
        """The renamed pipeline release."""
    def __init__(
        self,
        *,
        release: global___PipelineRelease | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release", b"release"]) -> None: ...

global___RenameOrganizationPipelineReleaseResponse = RenameOrganizationPipelineReleaseResponse

@typing_extensions.final
class TriggerOrganizationPipelineReleaseRequest(google.protobuf.message.Message):
    """TriggerOrganizationPipelineReleaseRequest represents a request to trigger a
    pinned release of an organization-owned pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline release, which allows its access by
    parent pipeline and ID.
    - Format:
    `organizations/{organization.id}/pipelines/{pipeline.id}/releases/{release.id}`.
    """
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Pipeline input parameters, it will be deprecated soon."""
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TriggerData]:
        """Data"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        data: collections.abc.Iterable[global___TriggerData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "inputs", b"inputs", "name", b"name"]) -> None: ...

global___TriggerOrganizationPipelineReleaseRequest = TriggerOrganizationPipelineReleaseRequest

@typing_extensions.final
class TriggerOrganizationPipelineReleaseResponse(google.protobuf.message.Message):
    """TriggerOrganizationPipelineReleaseResponse contains the pipeline execution
    results, i.e., the multiple model inference outputs.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUTS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Model inference outputs."""
    @property
    def metadata(self) -> global___TriggerMetadata:
        """Traces of the pipeline inference."""
    def __init__(
        self,
        *,
        outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        metadata: global___TriggerMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "outputs", b"outputs"]) -> None: ...

global___TriggerOrganizationPipelineReleaseResponse = TriggerOrganizationPipelineReleaseResponse

@typing_extensions.final
class TriggerAsyncOrganizationPipelineReleaseRequest(google.protobuf.message.Message):
    """TriggerOrganizationPipelineReleaseRequest represents a request to trigger a
    pinned release of an organization-owned pipeline asynchronously.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the pipeline release, which allows its access by
    parent pipeline and ID.
    - Format:
    `organizations/{organization.id}/pipelines/{pipeline.id}/releases/{release.id}`.
    """
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Pipeline input parameters, it will be deprecated soon."""
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TriggerData]:
        """Data"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        data: collections.abc.Iterable[global___TriggerData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "inputs", b"inputs", "name", b"name"]) -> None: ...

global___TriggerAsyncOrganizationPipelineReleaseRequest = TriggerAsyncOrganizationPipelineReleaseRequest

@typing_extensions.final
class TriggerAsyncOrganizationPipelineReleaseResponse(google.protobuf.message.Message):
    """TriggerAsyncOrganizationPipelineReleaseResponse contains the information to
    access the status of an asynchronous pipeline execution.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATION_FIELD_NUMBER: builtins.int
    @property
    def operation(self) -> google.longrunning.operations_pb2.Operation:
        """Long-running operation information."""
    def __init__(
        self,
        *,
        operation: google.longrunning.operations_pb2.Operation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["operation", b"operation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["operation", b"operation"]) -> None: ...

global___TriggerAsyncOrganizationPipelineReleaseResponse = TriggerAsyncOrganizationPipelineReleaseResponse

@typing_extensions.final
class GetOperationRequest(google.protobuf.message.Message):
    """GetOperationRequest represents a request to query a long-running operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATION_ID_FIELD_NUMBER: builtins.int
    operation_id: builtins.str
    """The name of the operation resource. Asynchronous methods will contain this
    information in their response.
    """
    def __init__(
        self,
        *,
        operation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["operation_id", b"operation_id"]) -> None: ...

global___GetOperationRequest = GetOperationRequest

@typing_extensions.final
class GetOperationResponse(google.protobuf.message.Message):
    """GetOperationResponse contains the long-running operation details."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATION_FIELD_NUMBER: builtins.int
    @property
    def operation(self) -> google.longrunning.operations_pb2.Operation:
        """The long-running operation."""
    def __init__(
        self,
        *,
        operation: google.longrunning.operations_pb2.Operation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["operation", b"operation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["operation", b"operation"]) -> None: ...

global___GetOperationResponse = GetOperationResponse

@typing_extensions.final
class ListPipelinesAdminRequest(google.protobuf.message.Message):
    """========== Private endpoints

    ListPipelinesAdminRequest represents a request by an admin to list all the
    pipelines. Admin users have access to pipelines from any user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    SHOW_DELETED_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of pipelines to return. If this parameter is
    unspecified, at most 10 pipelines will be returned. The cap value for this
    parameter is 100 (i.e. any value above that will be coerced to 100).
    """
    page_token: builtins.str
    """Page token."""
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired pipeline view in the response."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    - Example:
    `recipe.components.definition_name:"operator-definitions/2ac8be70-0f7a-4b61-a33d-098b8acfa6f3"`.
    """
    show_deleted: builtins.bool
    """Include soft-deleted pipelines in the result."""
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        view: global___Pipeline.View.ValueType | None = ...,
        filter: builtins.str | None = ...,
        show_deleted: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_show_deleted", b"_show_deleted"]) -> typing_extensions.Literal["show_deleted"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___ListPipelinesAdminRequest = ListPipelinesAdminRequest

@typing_extensions.final
class ListPipelinesAdminResponse(google.protobuf.message.Message):
    """ListPipelinesAdminResponse contains a list of pipelines requested by an
    admin user.
    For the moment, the pipeline recipes will be UID-based (permalink) instead
    of name-based. This is a temporary solution.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def pipelines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Pipeline]:
        """A list of pipeline resources."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of pipelines."""
    def __init__(
        self,
        *,
        pipelines: collections.abc.Iterable[global___Pipeline] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "pipelines", b"pipelines", "total_size", b"total_size"]) -> None: ...

global___ListPipelinesAdminResponse = ListPipelinesAdminResponse

@typing_extensions.final
class ListPipelineReleasesAdminRequest(google.protobuf.message.Message):
    """ListPipelinesReleaseAdminRequest represents a request by an admin to list
    all pipeline releases. Admin users have access to pipelines from any user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    SHOW_DELETED_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of releases to return. If this parameter is
    unspecified, at most 10 releases will be returned. The cap value for this
    parameter is 100 (i.e. any value above that will be coerced to 100).
    """
    page_token: builtins.str
    """Page token."""
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired pipeline view in the response."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    show_deleted: builtins.bool
    """Include soft-deleted pipelines in the result."""
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        view: global___Pipeline.View.ValueType | None = ...,
        filter: builtins.str | None = ...,
        show_deleted: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_show_deleted", b"_show_deleted"]) -> typing_extensions.Literal["show_deleted"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___ListPipelineReleasesAdminRequest = ListPipelineReleasesAdminRequest

@typing_extensions.final
class ListPipelineReleasesAdminResponse(google.protobuf.message.Message):
    """ListPipelineReleasesAdminResponse contains a list of pipeline releases
    requested by an admin user.
    For the moment, the pipeline recipes will be UID-based (permalink) instead
    of name-based. This is a temporary solution.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def releases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineRelease]:
        """A list of pipeline releases."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of pipeline releases."""
    def __init__(
        self,
        *,
        releases: collections.abc.Iterable[global___PipelineRelease] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "releases", b"releases", "total_size", b"total_size"]) -> None: ...

global___ListPipelineReleasesAdminResponse = ListPipelineReleasesAdminResponse

@typing_extensions.final
class LookUpPipelineAdminRequest(google.protobuf.message.Message):
    """LookUpPipelineAdminRequest represents a request by an admin to query a
    pipeline by its UID.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERMALINK_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    permalink: builtins.str
    """The permalink of the pipeline, which allows its access by UID.
    - Format: `pipelines/{pipeline.uid}`.
    """
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired pipeline view in the response."""
    def __init__(
        self,
        *,
        permalink: builtins.str = ...,
        view: global___Pipeline.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "permalink", b"permalink", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___LookUpPipelineAdminRequest = LookUpPipelineAdminRequest

@typing_extensions.final
class LookUpPipelineAdminResponse(google.protobuf.message.Message):
    """LookUpPipelineAdminResponse contains the requested pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_FIELD_NUMBER: builtins.int
    @property
    def pipeline(self) -> global___Pipeline:
        """The requested pipeline."""
    def __init__(
        self,
        *,
        pipeline: global___Pipeline | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline"]) -> None: ...

global___LookUpPipelineAdminResponse = LookUpPipelineAdminResponse

@typing_extensions.final
class ListPipelineRunsRequest(google.protobuf.message.Message):
    """ListPipelineRunsRequest is the request message for ListPipelineRuns."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """The ID of the owner of the pipeline."""
    pipeline_id: builtins.str
    """The ID of the pipeline for which the runs will be listed."""
    page: builtins.int
    """The page number to retrieve."""
    page_size: builtins.int
    """The maximum number of items per page to return. The default and cap values
    are 10 and 100, respectively.
    """
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    order_by: builtins.str
    """Order by field, with options for ordering by `id`, `create_time` or `update_time`.
    Format: `order_by=id` or `order_by=create_time desc`, default is `asc`.
    """
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        page: builtins.int = ...,
        page_size: builtins.int = ...,
        filter: builtins.str | None = ...,
        order_by: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_order_by", b"_order_by", "filter", b"filter", "order_by", b"order_by"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_order_by", b"_order_by", "filter", b"filter", "namespace_id", b"namespace_id", "order_by", b"order_by", "page", b"page", "page_size", b"page_size", "pipeline_id", b"pipeline_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_order_by", b"_order_by"]) -> typing_extensions.Literal["order_by"] | None: ...

global___ListPipelineRunsRequest = ListPipelineRunsRequest

@typing_extensions.final
class ListPipelineRunsByCreditOwnerRequest(google.protobuf.message.Message):
    """ListPipelineRunsByCreditOwnerRequest is the request message for ListPipelineRunsByCreditOwner."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    START_FIELD_NUMBER: builtins.int
    STOP_FIELD_NUMBER: builtins.int
    page: builtins.int
    """The page number to retrieve."""
    page_size: builtins.int
    """The maximum number of items per page to return. The default and cap values
    are 10 and 100, respectively.
    """
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    order_by: builtins.str
    """Order by field, with options for ordering by `id`, `create_time` or `update_time`.
    Format: `order_by=id` or `order_by=create_time desc`, default is `asc`.
    """
    @property
    def start(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Beginning of the time range from which the records will be fetched.
        The default value is the beginning of the current day, in UTC.
        """
    @property
    def stop(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End of the time range from which the records will be fetched.
        The default value is the current timestamp.
        """
    def __init__(
        self,
        *,
        page: builtins.int = ...,
        page_size: builtins.int = ...,
        filter: builtins.str | None = ...,
        order_by: builtins.str | None = ...,
        start: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        stop: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_order_by", b"_order_by", "_start", b"_start", "_stop", b"_stop", "filter", b"filter", "order_by", b"order_by", "start", b"start", "stop", b"stop"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_order_by", b"_order_by", "_start", b"_start", "_stop", b"_stop", "filter", b"filter", "order_by", b"order_by", "page", b"page", "page_size", b"page_size", "start", b"start", "stop", b"stop"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_order_by", b"_order_by"]) -> typing_extensions.Literal["order_by"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_start", b"_start"]) -> typing_extensions.Literal["start"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_stop", b"_stop"]) -> typing_extensions.Literal["stop"] | None: ...

global___ListPipelineRunsByCreditOwnerRequest = ListPipelineRunsByCreditOwnerRequest

@typing_extensions.final
class ListPipelineRunsResponse(google.protobuf.message.Message):
    """ListPipelineRunsResponse is the response message for ListPipelineRuns."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_RUNS_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    @property
    def pipeline_runs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineRun]:
        """The list of pipeline runs."""
    total_size: builtins.int
    """The total number of pipeline runs matching the request."""
    page: builtins.int
    """The current page number."""
    page_size: builtins.int
    """The number of items per page."""
    def __init__(
        self,
        *,
        pipeline_runs: collections.abc.Iterable[global___PipelineRun] | None = ...,
        total_size: builtins.int = ...,
        page: builtins.int = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page", b"page", "page_size", b"page_size", "pipeline_runs", b"pipeline_runs", "total_size", b"total_size"]) -> None: ...

global___ListPipelineRunsResponse = ListPipelineRunsResponse

@typing_extensions.final
class ListPipelineRunsByCreditOwnerResponse(google.protobuf.message.Message):
    """ListPipelineRunsByCreditOwnerResponse is the response message for ListPipelineRunsByCreditOwner."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_RUNS_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    @property
    def pipeline_runs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineRun]:
        """The list of pipeline runs."""
    total_size: builtins.int
    """The total number of pipeline runs matching the request."""
    page: builtins.int
    """The current page number."""
    page_size: builtins.int
    """The number of items per page."""
    def __init__(
        self,
        *,
        pipeline_runs: collections.abc.Iterable[global___PipelineRun] | None = ...,
        total_size: builtins.int = ...,
        page: builtins.int = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page", b"page", "page_size", b"page_size", "pipeline_runs", b"pipeline_runs", "total_size", b"total_size"]) -> None: ...

global___ListPipelineRunsByCreditOwnerResponse = ListPipelineRunsByCreditOwnerResponse

@typing_extensions.final
class ListComponentRunsRequest(google.protobuf.message.Message):
    """ListComponentRunsRequest is the request message for ListComponentRuns."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_RUN_ID_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    pipeline_run_id: builtins.str
    """The unique identifier of the pipeline run to list component runs for."""
    page: builtins.int
    """The page number to retrieve."""
    page_size: builtins.int
    """The maximum number of items per page to return. The default and cap values
    are 10 and 100, respectively.
    """
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    order_by: builtins.str
    """Order by field, with options for ordering by `id`, `create_time` or `update_time`.
    Format: `order_by=id` or `order_by=create_time desc`, default is `asc`.
    """
    view: global___Pipeline.View.ValueType
    """View allows clients to specify the desired run view in the response.
    The basic view excludes input / output data.
    """
    def __init__(
        self,
        *,
        pipeline_run_id: builtins.str = ...,
        page: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        filter: builtins.str | None = ...,
        order_by: builtins.str | None = ...,
        view: global___Pipeline.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_order_by", b"_order_by", "_page", b"_page", "_page_size", b"_page_size", "_view", b"_view", "filter", b"filter", "order_by", b"order_by", "page", b"page", "page_size", b"page_size", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_order_by", b"_order_by", "_page", b"_page", "_page_size", b"_page_size", "_view", b"_view", "filter", b"filter", "order_by", b"order_by", "page", b"page", "page_size", b"page_size", "pipeline_run_id", b"pipeline_run_id", "view", b"view"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_order_by", b"_order_by"]) -> typing_extensions.Literal["order_by"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page", b"_page"]) -> typing_extensions.Literal["page"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___ListComponentRunsRequest = ListComponentRunsRequest

@typing_extensions.final
class ListComponentRunsResponse(google.protobuf.message.Message):
    """ListComponentRunsResponse is the response message for ListComponentRuns."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPONENT_RUNS_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    @property
    def component_runs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComponentRun]:
        """The list of component runs."""
    total_size: builtins.int
    """The total number of component runs matching the request."""
    page: builtins.int
    """The current page number."""
    page_size: builtins.int
    """The number of items per page."""
    def __init__(
        self,
        *,
        component_runs: collections.abc.Iterable[global___ComponentRun] | None = ...,
        total_size: builtins.int = ...,
        page: builtins.int = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["component_runs", b"component_runs", "page", b"page", "page_size", b"page_size", "total_size", b"total_size"]) -> None: ...

global___ListComponentRunsResponse = ListComponentRunsResponse

@typing_extensions.final
class FileReference(google.protobuf.message.Message):
    """FileReference represents metadata for a file."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the file."""
    type: builtins.str
    """Format of the file (e.g., PDF, TXT, JPG)."""
    size: builtins.int
    """Size of the file in bytes."""
    url: builtins.str
    """URL of the file (e.g., S3 URL)."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: builtins.str = ...,
        size: builtins.int = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "size", b"size", "type", b"type", "url", b"url"]) -> None: ...

global___FileReference = FileReference

@typing_extensions.final
class PipelineRun(google.protobuf.message.Message):
    """PipelineRun represents a single execution of a pipeline."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_UID_FIELD_NUMBER: builtins.int
    PIPELINE_RUN_UID_FIELD_NUMBER: builtins.int
    PIPELINE_VERSION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TOTAL_DURATION_FIELD_NUMBER: builtins.int
    RUNNER_ID_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    OUTPUTS_FIELD_NUMBER: builtins.int
    RECIPE_SNAPSHOT_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    COMPLETE_TIME_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    CREDIT_AMOUNT_FIELD_NUMBER: builtins.int
    DATA_SPECIFICATION_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    pipeline_uid: builtins.str
    """Unique identifier for the pipeline."""
    pipeline_run_uid: builtins.str
    """Unique identifier for each run."""
    pipeline_version: builtins.str
    """Pipeline version used in the run."""
    status: common.run.v1alpha.run_pb2.RunStatus.ValueType
    """Current status of the run."""
    source: common.run.v1alpha.run_pb2.RunSource.ValueType
    """Origin of the run."""
    total_duration: builtins.int
    """Time taken to complete the run in milliseconds."""
    runner_id: builtins.str
    """Runner ID. If current viewing requester does not have enough permission, it will return null."""
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Pipeline input parameters."""
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Pipeline inference outputs."""
    @property
    def recipe_snapshot(self) -> google.protobuf.struct_pb2.Struct:
        """Snapshot of the pipeline recipe used for this run."""
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the run started execution."""
    @property
    def complete_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the run completed."""
    error: builtins.str
    """Error message if the run failed."""
    credit_amount: builtins.float
    """Credits used of internal accounting metric."""
    @property
    def data_specification(self) -> vdp.pipeline.v1beta.component_definition_pb2.DataSpecification:
        """Data specifications."""
    pipeline_id: builtins.str
    """The ID of the pipeline"""
    def __init__(
        self,
        *,
        pipeline_uid: builtins.str = ...,
        pipeline_run_uid: builtins.str = ...,
        pipeline_version: builtins.str = ...,
        status: common.run.v1alpha.run_pb2.RunStatus.ValueType = ...,
        source: common.run.v1alpha.run_pb2.RunSource.ValueType = ...,
        total_duration: builtins.int | None = ...,
        runner_id: builtins.str | None = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        recipe_snapshot: google.protobuf.struct_pb2.Struct | None = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        complete_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        error: builtins.str | None = ...,
        credit_amount: builtins.float | None = ...,
        data_specification: vdp.pipeline.v1beta.component_definition_pb2.DataSpecification | None = ...,
        pipeline_id: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_complete_time", b"_complete_time", "_credit_amount", b"_credit_amount", "_error", b"_error", "_pipeline_id", b"_pipeline_id", "_runner_id", b"_runner_id", "_total_duration", b"_total_duration", "complete_time", b"complete_time", "credit_amount", b"credit_amount", "data_specification", b"data_specification", "error", b"error", "pipeline_id", b"pipeline_id", "recipe_snapshot", b"recipe_snapshot", "runner_id", b"runner_id", "start_time", b"start_time", "total_duration", b"total_duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_complete_time", b"_complete_time", "_credit_amount", b"_credit_amount", "_error", b"_error", "_pipeline_id", b"_pipeline_id", "_runner_id", b"_runner_id", "_total_duration", b"_total_duration", "complete_time", b"complete_time", "credit_amount", b"credit_amount", "data_specification", b"data_specification", "error", b"error", "inputs", b"inputs", "outputs", b"outputs", "pipeline_id", b"pipeline_id", "pipeline_run_uid", b"pipeline_run_uid", "pipeline_uid", b"pipeline_uid", "pipeline_version", b"pipeline_version", "recipe_snapshot", b"recipe_snapshot", "runner_id", b"runner_id", "source", b"source", "start_time", b"start_time", "status", b"status", "total_duration", b"total_duration"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_complete_time", b"_complete_time"]) -> typing_extensions.Literal["complete_time"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_credit_amount", b"_credit_amount"]) -> typing_extensions.Literal["credit_amount"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_error", b"_error"]) -> typing_extensions.Literal["error"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_pipeline_id", b"_pipeline_id"]) -> typing_extensions.Literal["pipeline_id"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_runner_id", b"_runner_id"]) -> typing_extensions.Literal["runner_id"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_total_duration", b"_total_duration"]) -> typing_extensions.Literal["total_duration"] | None: ...

global___PipelineRun = PipelineRun

@typing_extensions.final
class ComponentRun(google.protobuf.message.Message):
    """ComponentRun represents the execution details of a single component within a pipeline run."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_RUN_UID_FIELD_NUMBER: builtins.int
    COMPONENT_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TOTAL_DURATION_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    COMPLETE_TIME_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    INPUTS_REFERENCE_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    OUTPUTS_REFERENCE_FIELD_NUMBER: builtins.int
    OUTPUTS_FIELD_NUMBER: builtins.int
    CREDIT_AMOUNT_FIELD_NUMBER: builtins.int
    pipeline_run_uid: builtins.str
    """Links to the parent PipelineRun."""
    component_id: builtins.str
    """Unique identifier for each pipeline component."""
    status: common.run.v1alpha.run_pb2.RunStatus.ValueType
    """Completion status of the component."""
    total_duration: builtins.int
    """Time taken to execute the component in milliseconds."""
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the component started execution."""
    @property
    def complete_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the component finished execution."""
    error: builtins.str
    """Error message if the component failed."""
    @property
    def inputs_reference(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FileReference]:
        """Input files for the run."""
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Component input parameters."""
    @property
    def outputs_reference(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FileReference]:
        """Output files from the run."""
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Component inference outputs."""
    credit_amount: builtins.float
    """Credits used of internal accounting metric."""
    def __init__(
        self,
        *,
        pipeline_run_uid: builtins.str = ...,
        component_id: builtins.str = ...,
        status: common.run.v1alpha.run_pb2.RunStatus.ValueType = ...,
        total_duration: builtins.int | None = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        complete_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        error: builtins.str | None = ...,
        inputs_reference: collections.abc.Iterable[global___FileReference] | None = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        outputs_reference: collections.abc.Iterable[global___FileReference] | None = ...,
        outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        credit_amount: builtins.float | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_complete_time", b"_complete_time", "_credit_amount", b"_credit_amount", "_error", b"_error", "_total_duration", b"_total_duration", "complete_time", b"complete_time", "credit_amount", b"credit_amount", "error", b"error", "start_time", b"start_time", "total_duration", b"total_duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_complete_time", b"_complete_time", "_credit_amount", b"_credit_amount", "_error", b"_error", "_total_duration", b"_total_duration", "complete_time", b"complete_time", "component_id", b"component_id", "credit_amount", b"credit_amount", "error", b"error", "inputs", b"inputs", "inputs_reference", b"inputs_reference", "outputs", b"outputs", "outputs_reference", b"outputs_reference", "pipeline_run_uid", b"pipeline_run_uid", "start_time", b"start_time", "status", b"status", "total_duration", b"total_duration"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_complete_time", b"_complete_time"]) -> typing_extensions.Literal["complete_time"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_credit_amount", b"_credit_amount"]) -> typing_extensions.Literal["credit_amount"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_error", b"_error"]) -> typing_extensions.Literal["error"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_total_duration", b"_total_duration"]) -> typing_extensions.Literal["total_duration"] | None: ...

global___ComponentRun = ComponentRun
